@@ -36,27 +36,57 @@
 #include "config.h"
 
 #include "pixmaps/editmodeon.xpm"
+#include "pixmaps/latchmodeon.xpm"
+#ifdef APPBUILD
 #include "pixmaps/patternremove.xpm"
 #include "pixmaps/patternstore.xpm"
-#include "pixmaps/latchmodeon.xpm"
+#endif
 
 
 
+#ifdef APPBUILD
 ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     int portCount, bool compactStyle,
     bool mutedAdd, bool inOutVisible, const QString& name, QWidget *parent):
-    QWidget(parent), midiWorker(p_midiWorker),
-    globStore(p_globStore), modified(false)
+    QWidget(parent),
+    midiWorker(p_midiWorker),
+    globStore(p_globStore),
+    modified(false)
 {
-    int l1;
-
     midiControl = new MidiControl(this);
-
-    manageBox = new ManageBox("Arp:", false, this);
+    manageBox = new ManageBox("Arp:", true, this);
+#else
+ArpWidget::ArpWidget(
+    bool compactStyle,
+    bool mutedAdd, bool inOutVisible, QWidget *parent):
+    QWidget(parent),
+    modified(false)
+{
+    midiWorker = NULL;
+#endif
+    int l1;
 
     // Input group box on left side
     QGroupBox *inBox = new QGroupBox(tr("Input"), this);
 
+    QLabel *enableRestartByKbdLabel = new QLabel(tr("&Restart"),inBox);
+    enableRestartByKbd = new QCheckBox(this);
+    connect(enableRestartByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableRestartByKbd(bool)));
+    enableRestartByKbdLabel->setBuddy(enableRestartByKbd);
+    enableRestartByKbd->setToolTip(tr("Restart pattern when a new note is received"));
+
+    QLabel *enableTrigByKbdLabel = new QLabel(tr("&Trigger"),inBox);
+    enableTrigByKbd = new QCheckBox(this);
+    connect(enableTrigByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableTrigByKbd(bool)));
+    enableTrigByKbdLabel->setBuddy(enableTrigByKbd);
+    enableTrigByKbd->setToolTip(tr("Retrigger pattern when a new note is received"));
+
+    QLabel *enableTrigLegatoLabel = new QLabel(tr("&Legato"),inBox);
+    enableTrigLegato = new QCheckBox(this);
+    connect(enableTrigLegato, SIGNAL(toggled(bool)), this, SLOT(updateTrigLegato(bool)));
+    enableTrigLegatoLabel->setBuddy(enableTrigLegato);
+    enableTrigLegato->setToolTip(tr("Retrigger / restart upon new legato note as well"));
+
     QLabel *chInLabel = new QLabel(tr("&Channel"), inBox);
     chIn = new QComboBox(inBox);
     for (l1 = 0; l1 < 16; l1++) chIn->addItem(QString::number(l1 + 1));
@@ -110,9 +140,15 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     inputFilterBox->setLayout(inputFilterBoxLayout);
 
     QGridLayout *inBoxLayout = new QGridLayout;
-    inBoxLayout->addWidget(chInLabel, 0, 0);
-    inBoxLayout->addWidget(chIn, 0, 1);
-    inBoxLayout->addWidget(inputFilterBox, 1, 0, 1, 2);
+    inBoxLayout->addWidget(enableRestartByKbdLabel, 0, 0);
+    inBoxLayout->addWidget(enableRestartByKbd, 0, 1);
+    inBoxLayout->addWidget(enableTrigByKbdLabel, 1, 0);
+    inBoxLayout->addWidget(enableTrigByKbd, 1, 1);
+    inBoxLayout->addWidget(enableTrigLegatoLabel, 2, 0);
+    inBoxLayout->addWidget(enableTrigLegato, 2, 1);
+    inBoxLayout->addWidget(chInLabel, 3, 0);
+    inBoxLayout->addWidget(chIn, 3, 1);
+    inBoxLayout->addWidget(inputFilterBox, 4, 0, 1, 2);
     if (compactStyle) {
         inBoxLayout->setMargin(2);
         inBoxLayout->setSpacing(1);
@@ -123,12 +159,6 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     // Output group box on right side
     QGroupBox *portBox = new QGroupBox(tr("Output"), this);
 
-    QLabel *portLabel = new QLabel(tr("&Port"), portBox);
-    portOut = new QComboBox(portBox);
-    portLabel->setBuddy(portOut);
-    for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
-    connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
-
     QLabel *channelLabel = new QLabel(tr("C&hannel"), portBox);
     channelOut = new QComboBox(portBox);
     channelLabel->setBuddy(channelOut);
@@ -137,8 +167,15 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
             SLOT(updateChannelOut(int)));
 
     QGridLayout *portBoxLayout = new QGridLayout;
-    portBoxLayout->addWidget(portLabel, 0, 0);
-    portBoxLayout->addWidget(portOut, 0, 1);
+#ifdef APPBUILD
+        QLabel *portLabel = new QLabel(tr("&Port"), portBox);
+        portOut = new QComboBox(portBox);
+        portLabel->setBuddy(portOut);
+        for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
+        connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
+        portBoxLayout->addWidget(portLabel, 0, 0);
+        portBoxLayout->addWidget(portOut, 0, 1);
+#endif
     portBoxLayout->addWidget(channelLabel, 1, 0);
     portBoxLayout->addWidget(channelOut, 1, 1);
     if (compactStyle) {
@@ -158,7 +195,9 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
 
     // Layout for left/right placements of in/out group boxes
     QVBoxLayout *inOutBoxLayout = new QVBoxLayout();
+#ifdef APPBUILD
     inOutBoxLayout->addWidget(manageBox);
+#endif
     inOutBoxLayout->addWidget(inBox);
     inOutBoxLayout->addWidget(portBox);
     inOutBoxLayout->addStretch();
@@ -178,6 +217,7 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     textEditAction->setCheckable(true);
     textEditButton->setDefaultAction(textEditAction);
 
+#ifdef APPBUILD
     textRemoveButton = new QToolButton(this);
     textRemoveAction = new QAction(QIcon(patternremove_xpm),
             tr("&Remove Pattern"), this);
@@ -193,6 +233,7 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
             SLOT(storeCurrentPattern()));
     textStoreAction->setEnabled(false);
     textStoreButton->setDefaultAction(textStoreAction);
+#endif
 
     patternPresetBox = new QComboBox(patternBox);
     loadPatternPresets();
@@ -203,8 +244,9 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     patternPresetBox->setMinimumContentsLength(20);
     connect(patternPresetBox, SIGNAL(activated(int)), this,
             SLOT(selectPatternPreset(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("PresetSwitch", patternPresetBox, 1);
-
+#endif
     muteOutAction = new QAction(tr("&Mute"),this);
     muteOutAction->setCheckable(true);
     connect(muteOutAction, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)));
@@ -212,8 +254,9 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     muteOut->setDefaultAction(muteOutAction);
     muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(35,20));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
-
+#endif
     deferChangesAction = new QAction("D", this);
     deferChangesAction->setToolTip(tr("Defer mute to pattern end"));
     deferChangesAction->setCheckable(true);
@@ -225,23 +268,13 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
 
     repeatPatternThroughChord = new QComboBox(patternBox);
     QStringList repeatPatternNames;
-    repeatPatternNames << tr("Static") << tr("Up") << tr("Down");
+    repeatPatternNames << tr("Static") << tr("Up") << tr("Down") << tr("Random");
     repeatPatternThroughChord->insertItems(0, repeatPatternNames);
     repeatPatternThroughChord->setToolTip(tr("Repeat mode"));
     connect(repeatPatternThroughChord, SIGNAL(currentIndexChanged(int)), this,
             SLOT(updateRepeatPattern(int)));
     repeatPatternThroughChord->setCurrentIndex(1);
 
-    triggerMode = new QComboBox(patternBox);
-    QStringList triggerModeNames;
-    triggerModeNames << tr("No trigger") << tr("Kbd restart") << tr("Kbd trigger")
-                        << tr("Kbd restart legato") << tr("Kbd trigger legato");
-    triggerMode->insertItems(0, triggerModeNames);
-    triggerMode->setToolTip(tr("Trigger Mode"));
-    connect(triggerMode, SIGNAL(currentIndexChanged(int)), this,
-            SLOT(updateTriggerMode(int)));
-    triggerMode->setCurrentIndex(0);
-
     latchModeButton = new QToolButton(this);
     latchModeAction = new QAction(QIcon(latchmodeon_xpm),
             tr("&Latch Mode"), this);
@@ -257,8 +290,10 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     }
     patternPresetLayout->addWidget(patternPresetBox);
     patternPresetLayout->addWidget(textEditButton);
+#ifdef APPBUILD
     patternPresetLayout->addWidget(textStoreButton);
     patternPresetLayout->addWidget(textRemoveButton);
+#endif
     patternPresetLayout->addStretch(2);
 
     QHBoxLayout *modeLayout = new QHBoxLayout;
@@ -270,7 +305,6 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     modeLayout->addWidget(muteOut);
     modeLayout->addWidget(deferChangesButton);
     modeLayout->addWidget(repeatPatternThroughChord);
-    modeLayout->addWidget(triggerMode);
     modeLayout->addWidget(latchModeButton);
     modeLayout->addStretch(2);
 
@@ -291,7 +325,7 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
 
     QWidget *screenBox = new QWidget(patternBox);
     QHBoxLayout *screenBoxLayout = new QHBoxLayout;
-    screen = new ArpScreen(patternBox);
+    screen = new ArpScreen(this);
     screenBox->setMinimumHeight(80);
     screenBoxLayout->addWidget(screen);
     screenBoxLayout->setMargin(2);
@@ -367,13 +401,14 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     envelopeBox->setFlat(true);
     envelopeBox->setLayout(envelopeBoxLayout);
 
-
-    parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
-    midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 2);
-    connect(parStore, SIGNAL(store(int, bool)),
-             this, SLOT(storeParams(int, bool)));
-    connect(parStore, SIGNAL(restore(int)),
-             this, SLOT(restoreParams(int)));
+#ifdef APPBUILD
+        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
+        midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 2);
+        connect(parStore, SIGNAL(store(int, bool)),
+                 this, SLOT(storeParams(int, bool)));
+        connect(parStore, SIGNAL(restore(int)),
+                 this, SLOT(restoreParams(int)));
+#endif
 
     muteOutAction->setChecked(mutedAdd);
 
@@ -391,55 +426,17 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
 
 ArpWidget::~ArpWidget()
 {
+#ifdef APPBUILD
     delete parStore;
+#endif
 }
 
+#ifdef APPBUILD
 MidiArp *ArpWidget::getMidiWorker()
 {
     return (midiWorker);
 }
 
-void ArpWidget::updateChIn(int value)
-{
-    midiWorker->chIn = value;
-    modified = true;
-}
-
-void ArpWidget::updateIndexIn(int value)
-{
-    if (indexIn[0] == sender()) {
-        midiWorker->indexIn[0] = value;
-    } else {
-        midiWorker->indexIn[1] = value;
-    }
-    checkIfInputFilterSet();
-    modified = true;
-}
-
-void ArpWidget::updateRangeIn(int value)
-{
-    if (rangeIn[0] == sender()) {
-        midiWorker->rangeIn[0] = value;
-    } else {
-        midiWorker->rangeIn[1] = value;
-    }
-    checkIfInputFilterSet();
-    modified = true;
-}
-
-void ArpWidget::checkIfInputFilterSet()
-{
-    if (((indexIn[1]->value() - indexIn[0]->value()) < 127)
-            || ((rangeIn[1]->value() - rangeIn[0]->value()) < 127)) {
-        inputFilterBox->setFlat(false);
-        inputFilterBox->setTitle(tr("Note Filter - ACTIVE"));
-    }
-    else {
-        inputFilterBox->setFlat(true);
-        inputFilterBox->setTitle(tr("Note Filter"));
-    }
-}
-
 void ArpWidget::writeData(QXmlStreamWriter& xml)
 {
     xml.writeStartElement(manageBox->name.left(3));
@@ -449,8 +446,6 @@ void ArpWidget::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("pattern", midiWorker->pattern);
             xml.writeTextElement("repeatMode", QString::number(
                 midiWorker->repeatPatternThroughChord));
-            xml.writeTextElement("triggerMode", QString::number(
-                triggerMode->currentIndex()));
             xml.writeTextElement("latchMode", QString::number(
                 latchModeAction->isChecked()));
         xml.writeEndElement();
@@ -466,6 +461,12 @@ void ArpWidget::writeData(QXmlStreamWriter& xml)
                 midiWorker->rangeIn[0]));
             xml.writeTextElement("rangeMax", QString::number(
                 midiWorker->rangeIn[1]));
+            xml.writeTextElement("restartByKbd", QString::number(
+                midiWorker->restartByKbd));
+            xml.writeTextElement("trigByKbd", QString::number(
+                midiWorker->trigByKbd));
+            xml.writeTextElement("trigLegato", QString::number(
+                midiWorker->trigLegato));
         xml.writeEndElement();
 
         xml.writeStartElement("output");
@@ -520,8 +521,6 @@ void ArpWidget::readData(QXmlStreamReader& xml)
                     patternText->setText(xml.readElementText());
                 else if (xml.name() == "repeatMode")
                     repeatPatternThroughChord->setCurrentIndex(xml.readElementText().toInt());
-                else if (xml.name() == "triggerMode")
-                    triggerMode->setCurrentIndex(xml.readElementText().toInt());
                 else if (xml.name() == "latchMode")
                     latchModeAction->setChecked(xml.readElementText().toInt());
                 else skipXmlElement(xml);
@@ -546,6 +545,12 @@ void ArpWidget::readData(QXmlStreamReader& xml)
                     rangeIn[0]->setValue(xml.readElementText().toInt());
                 else if (xml.name() == "rangeMax")
                     rangeIn[1]->setValue(xml.readElementText().toInt());
+                else if (xml.name() == "restartByKbd")
+                    enableRestartByKbd->setChecked(xml.readElementText().toInt());
+                else if (xml.name() == "trigByKbd")
+                    enableTrigByKbd->setChecked(xml.readElementText().toInt());
+                else if (xml.name() == "trigLegato")
+                    enableTrigLegato->setChecked(xml.readElementText().toInt());
                 else skipXmlElement(xml);
             }
         }
@@ -607,6 +612,48 @@ void ArpWidget::readData(QXmlStreamReader& xml)
     }
     modified = false;
 }
+#endif
+
+void ArpWidget::updateChIn(int value)
+{
+    if (midiWorker) midiWorker->chIn = value;
+    modified = true;
+}
+
+void ArpWidget::updateIndexIn(int value)
+{
+    if (indexIn[0] == sender()) {
+        if (midiWorker) midiWorker->indexIn[0] = value;
+    } else {
+        if (midiWorker) midiWorker->indexIn[1] = value;
+    }
+    checkIfInputFilterSet();
+    modified = true;
+}
+
+void ArpWidget::updateRangeIn(int value)
+{
+    if (rangeIn[0] == sender()) {
+        if (midiWorker) midiWorker->rangeIn[0] = value;
+    } else {
+        if (midiWorker) midiWorker->rangeIn[1] = value;
+    }
+    checkIfInputFilterSet();
+    modified = true;
+}
+
+void ArpWidget::checkIfInputFilterSet()
+{
+    if (((indexIn[1]->value() - indexIn[0]->value()) < 127)
+            || ((rangeIn[1]->value() - rangeIn[0]->value()) < 127)) {
+        inputFilterBox->setFlat(false);
+        inputFilterBox->setTitle(tr("Note Filter - ACTIVE"));
+    }
+    else {
+        inputFilterBox->setFlat(true);
+        inputFilterBox->setTitle(tr("Note Filter"));
+    }
+}
 
 void ArpWidget::setChIn(int value)
 {
@@ -629,12 +676,14 @@ void ArpWidget::setRangeIn(int index, int value)
 void ArpWidget::updateText(const QString& newtext)
 {
     patternPresetBox->setCurrentIndex(0);
+    if (!midiWorker) return;
     textRemoveAction->setEnabled(false);
     textStoreAction->setEnabled(true);
     midiWorker->updatePattern(newtext);
     screen->updateScreen(newtext, midiWorker->minOctave,
-                            midiWorker->maxOctave, midiWorker->minStepWidth,
-                            midiWorker->nSteps, midiWorker->patternMaxIndex);
+                    midiWorker->maxOctave, midiWorker->minStepWidth,
+                    midiWorker->nSteps, midiWorker->patternMaxIndex);
+
     modified = true;
 }
 
@@ -643,11 +692,15 @@ void ArpWidget::selectPatternPreset(int val)
     if (val < patternPresets.count()) {
         if (val) {
             patternText->setText(patternPresets.at(val));
+            if (!midiWorker) return;
             patternPresetBox->setCurrentIndex(val);
             textStoreAction->setEnabled(false);
             textRemoveAction->setEnabled(true);
-        } else
+        }
+        else {
+            if (!midiWorker) return;
             textRemoveAction->setEnabled(false);
+        }
         modified = true;
     }
 }
@@ -685,33 +738,45 @@ void ArpWidget::loadPatternPresets()
 
 void ArpWidget::updateRepeatPattern(int val)
 {
-    midiWorker->repeatPatternThroughChord = val;
+    if (midiWorker) midiWorker->repeatPatternThroughChord = val;
     modified = true;
 }
 
-void ArpWidget::updateTriggerMode(int val)
+void ArpWidget::updateEnableRestartByKbd(bool on)
 {
-    midiWorker->updateTriggerMode(val);
+    if (midiWorker) midiWorker->restartByKbd = on;
+    modified = true;
+}
+
+void ArpWidget::updateEnableTrigByKbd(bool on)
+{
+    if (midiWorker) midiWorker->trigByKbd = on;
+    modified = true;
+}
+
+void ArpWidget::updateTrigLegato(bool on)
+{
+    if (midiWorker) midiWorker->trigLegato = on;
     modified = true;
 }
 
 void ArpWidget::updateRandomLengthAmp(int val)
 {
-    midiWorker->updateRandomLengthAmp(val);
+    if (midiWorker) midiWorker->updateRandomLengthAmp(val);
     checkIfRandomSet();
     modified = true;
 }
 
 void ArpWidget::updateRandomTickAmp(int val)
 {
-    midiWorker->updateRandomTickAmp(val);
+    if (midiWorker) midiWorker->updateRandomTickAmp(val);
     checkIfRandomSet();
     modified = true;
 }
 
 void ArpWidget::updateRandomVelocityAmp(int val)
 {
-    midiWorker->updateRandomVelocityAmp(val);
+    if (midiWorker) midiWorker->updateRandomVelocityAmp(val);
     checkIfRandomSet();
     modified = true;
 }
@@ -731,14 +796,14 @@ void ArpWidget::checkIfRandomSet()
 
 void ArpWidget::updateAttackTime(int val)
 {
-    midiWorker->updateAttackTime(val);
+    if (midiWorker) midiWorker->updateAttackTime(val);
     checkIfEnvelopeSet();
     modified = true;
 }
 
 void ArpWidget::updateReleaseTime(int val)
 {
-    midiWorker->updateReleaseTime(val);
+    if (midiWorker) midiWorker->updateReleaseTime(val);
     checkIfEnvelopeSet();
     modified = true;
 }
@@ -845,21 +910,24 @@ void ArpWidget::setInOutBoxVisible(bool on)
 
 void ArpWidget::setMuted(bool on)
 {
+    if (!midiWorker) return;
     midiWorker->setMuted(on);
     screen->setMuted(midiWorker->isMuted);
+#ifdef APPBUILD
     parStore->ndc->setMuted(midiWorker->isMuted);
+#endif
     modified = true;
 }
 
 void ArpWidget::updateDeferChanges(bool on)
 {
-    midiWorker->updateDeferChanges(on);
+    if (midiWorker) midiWorker->updateDeferChanges(on);
     modified = true;
 }
 
 void ArpWidget::setLatchMode(bool on)
 {
-    midiWorker->setLatchMode(on);
+    if (midiWorker) midiWorker->setLatchMode(on);
     modified = true;
 }
 
@@ -877,28 +945,53 @@ void ArpWidget::setChannelOut(int value)
 
 void ArpWidget::updatePortOut(int value)
 {
-    midiWorker->portOut = value;
+    if (midiWorker) midiWorker->portOut = value;
     modified = true;
 }
 
 void ArpWidget::updateChannelOut(int value)
 {
-    midiWorker->channelOut = value;
+    if (midiWorker) midiWorker->channelOut = value;
     modified = true;
 }
 
+void ArpWidget::storeParams(int ix, bool empty)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doStoreParams(ix, empty);
+#else
+    (void)ix;
+    (void)empty;
+#endif
+}
+
+void ArpWidget::restoreParams(int ix)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doRestoreParams(ix);
+#else
+    (void)ix;
+#endif
+}
+
+#ifdef APPBUILD
 bool ArpWidget::isModified()
 {
-    return (modified || midiControl->isModified());
+    if (midiWorker)
+        return (modified || midiControl->isModified());
+    else
+        return modified;
 }
 
 void ArpWidget::setModified(bool m)
 {
     modified = m;
-    midiControl->setModified(m);
+    if (midiWorker) midiControl->setModified(m);
 }
 
-void ArpWidget::storeParams(int ix, bool empty)
+void ArpWidget::doStoreParams(int ix, bool empty)
 {
     parStore->temp.empty = empty;
     parStore->temp.muteOut = muteOut->isChecked();
@@ -919,7 +1012,7 @@ void ArpWidget::storeParams(int ix, bool empty)
     parStore->tempToList(ix);
 }
 
-void ArpWidget::restoreParams(int ix)
+void ArpWidget::doRestoreParams(int ix)
 {
     midiWorker->applyPendingParChanges();
     if (parStore->list.at(ix).empty) return;
@@ -1020,3 +1113,21 @@ void ArpWidget::updateDisplay()
     needsGUIUpdate = false;
     midiWorker->needsGUIUpdate = false;
 }
+
+void ArpWidget::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+#endif
