@@ -39,13 +39,16 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
+#ifdef APPBUILD
 #include "globstore.h"
-#include "midiarp.h"
-#include "slider.h"
-#include "arpscreen.h"
 #include "midicontrol.h"
 #include "managebox.h"
 #include "parstore.h"
+#endif
+
+#include "midiarp.h"
+#include "slider.h"
+#include "arpscreen.h"
 
 /*! @brief GUI class associated with and controlling a MidiArp worker
  *
@@ -62,28 +65,19 @@ class ArpWidget : public QWidget
 {
   Q_OBJECT
 
-  private:
-    QComboBox *chIn;                        // Channel of input events
-    QSpinBox *indexIn[2];                  // Index input
-    QSpinBox *rangeIn[2];                  // Parameter that is mapped, [0] low, [1] high boundary
+    MidiArp *midiWorker;
+#ifdef APPBUILD
+    GlobStore *globStore;
+#endif
+
+    bool modified;      /**< @brief Is set to True if unsaved parameter modifications exist */
+    bool needsGUIUpdate;
+
     QLabel *rangeInLabel, *indexInLabel;
-    QComboBox *channelOut, *portOut;        // Output channel / port (ALSA Sequencer)
-    QComboBox *repeatPatternThroughChord;
-    QComboBox *triggerMode;
-    QComboBox *patternPresetBox;
     QGroupBox *inputFilterBox, *randomBox, *envelopeBox;
-    QWidget *inOutBox;
     QToolButton *textEditButton, *textStoreButton, *textRemoveButton;
     QToolButton *latchModeButton;
     QAction *textEditAction, *textStoreAction, *textRemoveAction;
-    QAction *latchModeAction;
-    MidiArp *midiWorker;
-    GlobStore *globStore;
-    QLineEdit *patternText;
-    Slider *randomVelocity, *randomTick, *randomLength;
-    Slider *attackTime, *releaseTime;
-    bool modified;      /**< @brief Is set to True if unsaved parameter modifications exist */
-    bool needsGUIUpdate;
     int patternPresetBoxIndex;
 
     void loadPatternPresets();
@@ -99,27 +93,67 @@ class ArpWidget : public QWidget
  * @param mutedAdd If set to True, the module will be added in muted state
  * @param parent The parent widget of this module, i.e. MainWindow
  */
+#ifdef APPBUILD
     ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
             const QString& name = "", QWidget* parent=0);
-    ~ArpWidget();
 
     ParStore *parStore;
     MidiControl *midiControl;
-    ArpScreen *screen;
     ManageBox *manageBox;
+#else
+    ArpWidget(
+            bool compactStyle,
+            bool mutedAdd = false, bool inOutVisible = true,
+            QWidget* parent=0);
+#endif
+    ~ArpWidget();
+
+    ArpScreen *screen;
+
+    QComboBox *chIn;                        // Channel of input events
+    QComboBox *channelOut, *portOut;        // Output channel / port (ALSA Sequencer)
+    QComboBox *repeatPatternThroughChord;
+    QComboBox *patternPresetBox;
+    QWidget *inOutBox;
+    QSpinBox *indexIn[2];                  // Index input
+    QSpinBox *rangeIn[2];                  // Parameter that is mapped, [0] low, [1] high boundary
+    Slider *randomVelocity, *randomTick, *randomLength;
+    Slider *attackTime, *releaseTime;
+    QLineEdit *patternText;
 
     QStringList patternPresets, patternNames;
     QAction *muteOutAction;
     QAction *deferChangesAction;
     QToolButton *muteOut;
     QAction* hideInOutBoxAction;
+    QAction *latchModeAction;
+    QCheckBox *enableRestartByKbd;
+    QCheckBox *enableTrigByKbd;
+    QCheckBox *enableTrigLegato;
 
     void setChIn(int value);
     void setIndexIn(int index, int value);
     void setRangeIn(int index, int value);
 
+/*!
+* @brief Settor for the ArpWidget::channelOut spinbox setting the output
+* channel of this module.
+* @param value Number of the output channel to send data to
+*
+*/
+
+    void setChannelOut(int value);
+/*!
+* @brief Settor for the ArpWidget::portOut spinbox setting the output
+* port of this module.
+* @param value Number of the output port to send data to
+*
+*/
+    void setPortOut(int value);
+
+#ifdef APPBUILD
     //these members are common to all modules
 /*!
 * @brief This function reads all parameters of this module from an XML stream
@@ -142,20 +176,6 @@ class ArpWidget : public QWidget
 */
     MidiArp *getMidiWorker();
 /*!
-* @brief Settor for the ArpWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
-*
-*/
-    void setChannelOut(int value);
-/*!
-* @brief Settor for the ArpWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void setPortOut(int value);
-/*!
 * @brief Accessor for ArpWidget::modified.
 * @return True if unsaved parameter modifications exist
 *
@@ -167,6 +187,22 @@ class ArpWidget : public QWidget
 *
 */
     void setModified(bool);
+    void skipXmlElement(QXmlStreamReader& xml);
+/*!
+* @brief This function stores some module parameters in a parameter
+* list object
+*
+* @param Position index in the parameter list
+*/
+    void doStoreParams(int ix, bool empty);
+/*!
+* @brief This function restores some module parameters from the parameter
+* list object
+*
+* @param Position index in the parameter list
+*/
+    void doRestoreParams(int ix);
+#endif
 
     int getNextTick() { return midiWorker->nextTick; }
 
@@ -193,7 +229,6 @@ class ArpWidget : public QWidget
     void checkIfInputFilterSet();
     void updateText(const QString& newtext);
     void updateRepeatPattern(int);
-    void updateTriggerMode(int);
     void selectPatternPreset(int);
     void updatePatternPresets(const QString& n, const QString& p, int index);
     void openTextEditWindow(bool on);
@@ -205,11 +240,12 @@ class ArpWidget : public QWidget
     void setInOutBoxVisible(bool on);
 
     void updateChIn(int value);
+    void updateEnableRestartByKbd(bool on);
+    void updateEnableTrigByKbd(bool on);
+    void updateTrigLegato(bool on);
     void updateIndexIn(int value);
     void updateRangeIn(int value);
 
-    void updateDisplay();
-
  /*! @brief Slot for ArpWidget::latchModeAction.
   * Will cause notes remaining in MidiArp::latchBuffer until new
   * stakato note received */
@@ -249,21 +285,15 @@ class ArpWidget : public QWidget
 * @param on Set to True for deferring parameter changes to pattern end
 */
     void updateDeferChanges(bool on);
-/*!
-* @brief This function stores some module parameters in a parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
+
     void storeParams(int ix, bool empty = false);
-/*!
-* @brief This function restores some module parameters from the parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
     void restoreParams(int ix);
+
+#ifdef APPBUILD
     void handleController(int ccnumber, int channel, int value);
+    void updateDisplay();
+#endif
+
     int getGrooveIndex() { return midiWorker->getGrooveIndex(); }
 };
 
