@@ -37,6 +37,8 @@ public:
     bool forwardUnmatched, queueStatus;
     int portUnmatched;
     QString jsFilename;
+    uint trStartingTick;
+    uint trLoopingTick;
 
     virtual void resetTick(unsigned int tick = 0)
     {
@@ -80,13 +82,18 @@ public:
     {
         portUnmatched = id;
     }
-    virtual void setTempo(int bpm)
+    virtual void setTempo(double bpm)
     {
         tempo = bpm;
         internalTempo = bpm;
     }
 
-    virtual bool callJack(int portcount) = 0;
+    virtual void requestTempo(double bpm)
+    {
+        requestedTempo = bpm;
+    }
+
+    virtual bool callJack(int portcount, const QString & clientname=PACKAGE) = 0;
 
     // duration is in ticks and is valid only for note on events
     virtual void sendMidiEvent(MidiEvent ev, int n_tick, unsigned int outport, unsigned int duration = 0) = 0;
@@ -148,8 +155,9 @@ protected:
     uint64_t m_backend_rate;    // samples(?) per minute (granularity)
     unsigned int m_current_tick;
     unsigned int m_next_tick;
+
     uint64_t m_tpm;             // ticks per minute
-    int tempo, internalTempo;
+    double tempo, internalTempo, requestedTempo;
     int portCount;
 };
 
