@@ -395,3 +395,20 @@ void GlobStore::updateDisplay()
     needsGUIUpdate = false;
     setDispState(dispReqIx, dispReqSelected);
 }
+
+void GlobStore::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
