@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009, 2010, 2011, 2012 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -51,6 +51,7 @@ Indicator::Indicator(int size, QChar modType, QWidget* parent) : QWidget (parent
         default: fillColor = QColor(200, 160, 0);
     }
     needsRedraw = false;
+    isMuted = false;
 }
 
 Indicator::~Indicator()
@@ -63,8 +64,9 @@ void Indicator::paintEvent(QPaintEvent*)
     QPainter p(this);
     QPen pen;
     pen.setWidth(2);
-    pen.setColor(QColor(0, 0, 0));
-    p.setBrush(fillColor);
+    pen.setColor(QColor(0, 0, 0, (int)!isMuted * 200 + 55));
+    if (isMuted) p.setBrush(fillColor.lighter(220));
+    else p.setBrush(fillColor);
     p.setPen(pen);
     p.setRenderHint(QPainter::Antialiasing, true);
     QRectF r(5.0, 5.0, p_size, p_size);
@@ -84,6 +86,12 @@ void Indicator::updateDraw()
     update();
 }
 
+void Indicator::setMuted(bool on)
+{
+    isMuted = on;
+    needsRedraw = true;
+}
+
 QSize Indicator::sizeHint() const
 {
     return QSize(p_size, p_size);
