@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009, 2010, 2011, 2012 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ class Indicator : public QWidget
     int p_angle;
     int p_size;
     bool needsRedraw;
+    bool isMuted;
     QColor fillColor;
 
   protected:
@@ -53,6 +54,7 @@ class Indicator : public QWidget
 
   public slots:
     void updatePercent(int percent);
+    void setMuted(bool on);
     void updateDraw();
 };
 
