@@ -73,15 +73,6 @@ void LfoScreen::paintEvent(QPaintEvent*)
     int grooveTmp = 0;
     l2 = 0;
 
-    //Grid
-    if (p_data.isEmpty()) return;
-    npoints = p_data.count() - 1;
-    nsteps = p_data.at(npoints).tick / TPQN;
-    beatRes = npoints / nsteps;
-    beatDiv = (npoints > 64) ? 64 / nsteps : beatRes;
-    xscale = (w - 2 * LFOSCR_HMARG);
-    yscale = h - 2 * LFOSCR_VMARG;
-
     //Beryll Filled Frame
     if (isMuted)
         p.fillRect(0, 0, w, h, QColor(70, 70, 70));
@@ -91,6 +82,16 @@ void LfoScreen::paintEvent(QPaintEvent*)
     p.setWindow(0, 0, w, h);
     p.setPen(QColor(160, 20, 20));
 
+    //Grid
+    if (p_data.isEmpty()) return;
+    npoints = p_data.count() - 1;
+    nsteps = p_data.at(npoints).tick / TPQN;
+    if (!nsteps) nsteps = 1;
+    beatRes = npoints / nsteps;
+    beatDiv = (npoints > 64) ? 64 / nsteps : beatRes;
+    xscale = (w - 2 * LFOSCR_HMARG);
+    yscale = h - 2 * LFOSCR_VMARG;
+
     //Beat separators
     for (l1 = 0; l1 < nsteps + 1; l1++) {
 
@@ -186,19 +187,20 @@ void LfoScreen::setMuted(bool on)
 
 void LfoScreen::mouseMoveEvent(QMouseEvent *event)
 {
-    mouseX = event->x();
-    mouseY = event->y();
-    bool cl = false;
-
-    mouseX = clip(mouseX, LFOSCR_HMARG, xMax, &cl);
-    mouseY = clip(mouseY, LFOSCR_VMARG + 1, h - LFOSCR_VMARG, &cl);
-    emit mouseMoved(((double)mouseX - LFOSCR_HMARG) /
-                            ((double)xMax - LFOSCR_HMARG + .2),
-                1. - ((double)mouseY - LFOSCR_VMARG) /
-                (h - 2 * LFOSCR_VMARG), event->buttons());
+    emitMouseEvent(event, 0);
 }
 
 void LfoScreen::mousePressEvent(QMouseEvent *event)
+{
+    emitMouseEvent(event, 1);
+}
+
+void LfoScreen::mouseReleaseEvent(QMouseEvent *event)
+{
+    emitMouseEvent(event, 2);
+}
+
+void LfoScreen::emitMouseEvent(QMouseEvent *event, int pressed)
 {
     mouseX = event->x();
     mouseY = event->y();
@@ -207,10 +209,10 @@ void LfoScreen::mousePressEvent(QMouseEvent *event)
     mouseX = clip(mouseX, LFOSCR_HMARG, xMax, &cl);
     mouseY = clip(mouseY, LFOSCR_VMARG + 1, h - LFOSCR_VMARG, &cl);
 
-    emit mousePressed(((double)mouseX - LFOSCR_HMARG) /
+    emit mouseEvent(((double)mouseX - LFOSCR_HMARG) /
                             ((double)xMax - LFOSCR_HMARG + .2),
                 1. - ((double)mouseY - LFOSCR_VMARG) /
-                (h - 2 * LFOSCR_VMARG), event->buttons());
+                (h - 2 * LFOSCR_VMARG), event->buttons(), pressed);
 }
 
 void LfoScreen::wheelEvent(QWheelEvent *event)
