@@ -21,17 +21,14 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  */
-
+#include <cstdio>
 #include <QBoxLayout>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
 #include <QMessageBox>
 
-#include "midilfo.h"
 #include "lfowidget.h"
-#include "slider.h"
-#include "lfoscreen.h"
 
 #include "pixmaps/lfowsine.xpm"
 #include "pixmaps/lfowsawup.xpm"
@@ -43,17 +40,27 @@
 #include "config.h"
 
 
+#ifdef APPBUILD
 LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     int portCount, bool compactStyle,
     bool mutedAdd, bool inOutVisible, const QString& name, QWidget *parent):
-    QWidget(parent), midiWorker(p_midiWorker),
-    globStore(p_globStore), modified(false)
+    QWidget(parent),
+    midiWorker(p_midiWorker),
+    globStore(p_globStore),
+    modified(false)
 {
-    int l1;
-
     midiControl = new MidiControl(this);
-
     manageBox = new ManageBox("LFO:", true, this);
+#else
+LfoWidget::LfoWidget(
+    bool compactStyle,
+    bool mutedAdd, bool inOutVisible, QWidget *parent):
+    QWidget(parent),
+    modified(false)
+{
+    midiWorker = NULL;
+#endif
+    int l1;
 
     // Input group box on right top
     QGroupBox *inBox = new QGroupBox(tr("Input"), this);
@@ -138,11 +145,6 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     connect(ccnumberBox, SIGNAL(valueChanged(int)), this,
             SLOT(updateCcnumber(int)));
 
-    QLabel *portLabel = new QLabel(tr("&Port"), portBox);
-    portOut = new QComboBox(portBox);
-    portLabel->setBuddy(portOut);
-    for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
-    connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
 
     QLabel *channelLabel = new QLabel(tr("C&hannel"), portBox);
     channelOut = new QComboBox(portBox);
@@ -155,8 +157,15 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     QGridLayout *portBoxLayout = new QGridLayout;
     portBoxLayout->addWidget(ccnumberLabel, 0, 0);
     portBoxLayout->addWidget(ccnumberBox, 0, 1);
-    portBoxLayout->addWidget(portLabel, 1, 0);
-    portBoxLayout->addWidget(portOut, 1, 1);
+#ifdef APPBUILD
+        QLabel *portLabel = new QLabel(tr("&Port"), portBox);
+        portOut = new QComboBox(portBox);
+        portLabel->setBuddy(portOut);
+        for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
+        connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
+        portBoxLayout->addWidget(portLabel, 1, 0);
+        portBoxLayout->addWidget(portOut, 1, 1);
+#endif
     portBoxLayout->addWidget(channelLabel, 2, 0);
     portBoxLayout->addWidget(channelOut, 2, 1);
 
@@ -179,7 +188,10 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     connect(hideInOutBoxAction, SIGNAL(toggled(bool)), this, SLOT(setInOutBoxVisible(bool)));
 
     QVBoxLayout *inOutBoxLayout = new QVBoxLayout;
+
+#ifdef APPBUILD
     inOutBoxLayout->addWidget(manageBox);
+#endif
     inOutBoxLayout->addWidget(inBox);
     inOutBoxLayout->addWidget(portBox);
     inOutBoxLayout->addStretch();
@@ -195,10 +207,8 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
         tr("Right button to mute points\nLeft button to draw custom wave\nWheel to change offset"));
     screen->setMinimumHeight(80);
 
-    connect(screen, SIGNAL(mouseMoved(double, double, int)), this,
-            SLOT(mouseMoved(double, double, int)));
-    connect(screen, SIGNAL(mousePressed(double, double, int)), this,
-            SLOT(mousePressed(double, double, int)));
+    connect(screen, SIGNAL(mouseEvent(double, double, int, int)), this,
+            SLOT(mouseEvent(double, double, int, int)));
     connect(screen, SIGNAL(mouseWheel(int)), this,
             SLOT(mouseWheel(int)));
 
@@ -220,8 +230,9 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
 
     connect(waveFormBox, SIGNAL(activated(int)), this,
             SLOT(updateWaveForm(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("WaveForm", waveFormBox, 3);
-
+#endif
 
     QLabel *freqBoxLabel = new QLabel(tr("&Frequency"),
             waveBox);
@@ -232,15 +243,16 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
         << "1/2" << "3/4" << "1" << "2" << "3"
         << "4" << "5" << "6" << "7" << "8";
     freqBox->insertItems(0, names);
-    freqBox->setCurrentIndex(6);
-    freqBoxIndex = 6;
+    freqBox->setCurrentIndex(4);
+    freqBoxIndex = 4;
     freqBox->setToolTip(
             tr("Frequency (cycles/beat): Number of wave cycles produced every beat"));
     freqBox->setMinimumContentsLength(3);
     connect(freqBox, SIGNAL(activated(int)), this,
             SLOT(updateFreq(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Frequency", freqBox, 4);
-
+#endif
     QLabel *resBoxLabel = new QLabel(tr("&Resolution"),
             waveBox);
     resBox = new QComboBox(waveBox);
@@ -248,15 +260,16 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     names.clear();
     names << "1" << "2" << "4" << "8" << "16" << "32" << "64" << "96" << "192";
     resBox->insertItems(0, names);
-    resBox->setCurrentIndex(4);
-    resBoxIndex = 4;
+    resBox->setCurrentIndex(2);
+    resBoxIndex = 2;
     resBox->setToolTip(
             tr("Resolution (events/beat): Number of events produced every beat"));
     resBox->setMinimumContentsLength(3);
     connect(resBox, SIGNAL(activated(int)), this,
             SLOT(updateRes(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Resolution", resBox, 6);
-
+#endif
     QLabel *sizeBoxLabel = new QLabel(tr("&Length"), waveBox);
     sizeBox = new QComboBox(waveBox);
     sizeBoxLabel->setBuddy(sizeBox);
@@ -264,25 +277,27 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     names << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8"
             << "12" << "16" << "24" << "32" ;
     sizeBox->insertItems(0, names);
-    sizeBox->setCurrentIndex(0);
-    sizeBoxIndex = 0;
+    sizeBox->setCurrentIndex(3);
+    sizeBoxIndex = 3;
     sizeBox->setToolTip(tr("Length of LFO wave in beats"));
     sizeBox->setMinimumContentsLength(3);
     connect(sizeBox, SIGNAL(activated(int)), this,
             SLOT(updateSize(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Size", sizeBox, 7);
-
+#endif
     loopBox = new QComboBox(waveBox);
     names.clear();
-    names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-";
+    names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-" << "RANDM";
     loopBox->insertItems(0, names);
     loopBox->setCurrentIndex(0);
     loopBox->setToolTip(tr("Loop, bounce or play once going forward or backward"));
     loopBox->setMinimumContentsLength(5);
     connect(loopBox, SIGNAL(activated(int)), this,
             SLOT(updateLoop(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("LoopMode", loopBox, 8);
-
+#endif
     muteOutAction = new QAction(tr("&Mute"),this);
     muteOutAction->setCheckable(true);
     connect(muteOutAction, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)));
@@ -290,8 +305,9 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     muteOut->setDefaultAction(muteOutAction);
     muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(35,20));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
-
+#endif
     deferChangesAction = new QAction("D", this);
     deferChangesAction->setToolTip(tr("Defer mute to pattern end"));
     deferChangesAction->setCheckable(true);
@@ -309,21 +325,24 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     recordButton->setDefaultAction(recordAction);
     recordButtonLabel->setBuddy(recordButton);
     connect(recordAction, SIGNAL(toggled(bool)), this, SLOT(setRecord(bool)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("RecordToggle", recordButton, 5);
-
+#endif
     amplitude = new Slider(0, 127, 1, 8, 64, Qt::Horizontal,
             tr("&Amplitude"), waveBox);
     connect(amplitude, SIGNAL(valueChanged(int)), this,
             SLOT(updateAmp(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Amplitude", amplitude, 1);
-
+#endif
 
     offset = new Slider(0, 127, 1, 8, 0, Qt::Horizontal,
             tr("&Offset"), waveBox);
     connect(offset, SIGNAL(valueChanged(int)), this,
             SLOT(updateOffs(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Offset", offset, 2);
-
+#endif
     QVBoxLayout* sliderLayout = new QVBoxLayout;
     sliderLayout->addWidget(amplitude);
     sliderLayout->addWidget(offset);
@@ -370,29 +389,31 @@ LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     widgetLayout->addWidget(waveBox, 1);
     widgetLayout->addWidget(hideInOutBoxButton, 0);
     widgetLayout->addWidget(inOutBox, 0);
-
-    parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
-    midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 9);
-    connect(parStore, SIGNAL(store(int, bool)),
-             this, SLOT(storeParams(int, bool)));
-    connect(parStore, SIGNAL(restore(int)),
-             this, SLOT(restoreParams(int)));
+#ifdef APPBUILD
+        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
+        midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 9);
+        connect(parStore, SIGNAL(store(int, bool)),
+                 this, SLOT(storeParams(int, bool)));
+        connect(parStore, SIGNAL(restore(int)),
+                 this, SLOT(restoreParams(int)));
+#endif
 
     muteOutAction->setChecked(mutedAdd);
 
     setLayout(widgetLayout);
     updateAmp(64);
-
-    lastMute = false;
     dataChanged = false;
     needsGUIUpdate = false;
 }
 
 LfoWidget::~LfoWidget()
 {
+#ifdef APPBUILD
     delete parStore;
+#endif
 }
 
+#ifdef APPBUILD
 MidiLfo *LfoWidget::getMidiWorker()
 {
     return (midiWorker);
@@ -402,7 +423,6 @@ void LfoWidget::writeData(QXmlStreamWriter& xml)
 {
     QByteArray tempArray;
     int l1;
-
     xml.writeStartElement(manageBox->name.left(3));
     xml.writeAttribute("name", manageBox->name.mid(manageBox->name.indexOf(':') + 1));
     xml.writeAttribute("inOutVisible", QString::number(inOutBox->isVisible()));
@@ -474,7 +494,6 @@ void LfoWidget::writeData(QXmlStreamWriter& xml)
         midiControl->writeData(xml);
 
         parStore->writeData(xml);
-
     xml.writeEndElement();
 }
 
@@ -621,6 +640,7 @@ void LfoWidget::readData(QXmlStreamReader& xml)
     updateWaveForm(wvtmp);
     modified = false;
 }
+#endif
 
 void LfoWidget::loadWaveForms()
 {
@@ -630,7 +650,8 @@ void LfoWidget::loadWaveForms()
 
 void LfoWidget::updateCcnumber(int val)
 {
-    midiWorker->ccnumber = val;
+    if (midiWorker)
+        midiWorker->ccnumber = val;
     modified = true;
 }
 
@@ -642,36 +663,36 @@ void LfoWidget::setChIn(int value)
 
 void LfoWidget::updateChIn(int val)
 {
-    midiWorker->chIn = val;
+    if (midiWorker) midiWorker->chIn = val;
     modified = true;
 }
 
 void LfoWidget::updateCcnumberIn(int val)
 {
-    midiWorker->ccnumberIn = val;
+    if (midiWorker) midiWorker->ccnumberIn = val;
     modified = true;
 }
 void LfoWidget::updateEnableNoteOff(bool on)
 {
-    midiWorker->enableNoteOff = on;
+    if (midiWorker) midiWorker->enableNoteOff = on;
     modified = true;
 }
 
 void LfoWidget::updateEnableRestartByKbd(bool on)
 {
-    midiWorker->restartByKbd = on;
+    if (midiWorker) midiWorker->restartByKbd = on;
     modified = true;
 }
 
 void LfoWidget::updateEnableTrigByKbd(bool on)
 {
-    midiWorker->trigByKbd = on;
+    if (midiWorker) midiWorker->trigByKbd = on;
     modified = true;
 }
 
 void LfoWidget::updateTrigLegato(bool on)
 {
-    midiWorker->trigLegato = on;
+    if (midiWorker) midiWorker->trigLegato = on;
     modified = true;
 }
 
@@ -679,11 +700,11 @@ void LfoWidget::updateWaveForm(int val)
 {
     if (val > 5) return;
     waveFormBoxIndex = val;
-    midiWorker->updateWaveForm(val);
-    midiWorker->getData(&data);
-    screen->updateData(data);
+    if (midiWorker) midiWorker->updateWaveForm(val);
+    if (midiWorker) midiWorker->getData(&data);
+    if (midiWorker) screen->updateData(data);
     bool isCustom = (val == 5);
-    if (isCustom) midiWorker->newCustomOffset();
+    if (isCustom && midiWorker) midiWorker->newCustomOffset();
     amplitude->setDisabled(isCustom);
     freqBox->setDisabled(isCustom);
     modified = true;
@@ -692,6 +713,7 @@ void LfoWidget::updateWaveForm(int val)
 
 void LfoWidget::updateScreen(int val)
 {
+    if (!midiWorker) return;
     if (!midiWorker->isRecording)
         cursor->updatePosition(val);
 }
@@ -700,9 +722,9 @@ void LfoWidget::updateFreq(int val)
 {
     if (val > 13) return;
     freqBoxIndex = val;
-    midiWorker->updateFrequency(lfoFreqValues[val]);
-    midiWorker->getData(&data);
-    screen->updateData(data);
+    if (midiWorker) midiWorker->updateFrequency(lfoFreqValues[val]);
+    if (midiWorker) midiWorker->getData(&data);
+    if (midiWorker) screen->updateData(data);
     modified = true;
 }
 
@@ -710,10 +732,10 @@ void LfoWidget::updateRes(int val)
 {
     if (val > 8) return;
     resBoxIndex = val;
-    midiWorker->updateResolution(lfoResValues[val]);
-    midiWorker->getData(&data);
-    screen->updateData(data);
-    midiWorker->newCustomOffset();
+    if (midiWorker) midiWorker->updateResolution(lfoResValues[val]);
+    if (midiWorker) midiWorker->getData(&data);
+    if (midiWorker) screen->updateData(data);
+    if (midiWorker && (waveFormBoxIndex == 5)) midiWorker->newCustomOffset();
     modified = true;
 }
 
@@ -721,22 +743,24 @@ void LfoWidget::updateSize(int val)
 {
     if (val > 11) return;
     sizeBoxIndex = val;
+    if (!midiWorker) return;
     midiWorker->updateSize(sizeBox->currentText().toInt());
     midiWorker->getData(&data);
     screen->updateData(data);
-    midiWorker->newCustomOffset();
+    if (waveFormBoxIndex == 5) midiWorker->newCustomOffset();
     modified = true;
 }
 
 void LfoWidget::updateLoop(int val)
 {
-    if (val > 5) return;
-    midiWorker->updateLoop(val);
+    if (val > 6) return;
+    if (midiWorker) midiWorker->updateLoop(val);
     modified = true;
 }
 
 void LfoWidget::updateAmp(int val)
 {
+    if (!midiWorker) return;
     midiWorker->updateAmplitude(val);
     midiWorker->getData(&data);
     screen->updateData(data);
@@ -745,6 +769,7 @@ void LfoWidget::updateAmp(int val)
 
 void LfoWidget::updateOffs(int val)
 {
+    if (!midiWorker) return;
     midiWorker->updateOffset(val);
     midiWorker->getData(&data);
     screen->updateData(data);
@@ -753,41 +778,21 @@ void LfoWidget::updateOffs(int val)
 
 void LfoWidget::copyToCustom()
 {
-    midiWorker->copyToCustom();
+    if (midiWorker) midiWorker->copyToCustom();
     waveFormBox->setCurrentIndex(5);
     updateWaveForm(5);
     modified = true;
 }
 
-void LfoWidget::mouseMoved(double mouseX, double mouseY, int buttons)
+void LfoWidget::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
 {
-    if (buttons == 2) {
-        midiWorker->setMutePoint(mouseX, lastMute);
-    }
-    else {
-        if (waveFormBox->currentIndex() < 5) {
-            copyToCustom();
-        }
-        midiWorker->setCustomWavePoint(mouseX, mouseY, false);
-        midiWorker->newCustomOffset();
-    }
-    midiWorker->dataChanged = true;
-    modified = true;
-}
+    if (!midiWorker) emit mouseSig(mouseX, mouseY, buttons, pressed);
+    else midiWorker->mouseEvent(mouseX, mouseY, buttons, pressed);
 
-void LfoWidget::mousePressed(double mouseX, double mouseY, int buttons)
-{
-    if (buttons == 2) {
-        lastMute = midiWorker->toggleMutePoint(mouseX);
+    if (waveFormBox->currentIndex() != 5) {
+        waveFormBox->setCurrentIndex(5);
+        updateWaveForm(5);
     }
-    else {
-        if (waveFormBox->currentIndex() < 5) {
-            copyToCustom();
-        }
-        midiWorker->setCustomWavePoint(mouseX, mouseY, true);
-        midiWorker->newCustomOffset();
-    }
-    midiWorker->dataChanged = true;
     modified = true;
 }
 
@@ -807,21 +812,24 @@ void LfoWidget::setInOutBoxVisible(bool on)
 
 void LfoWidget::setMuted(bool on)
 {
+    if (!midiWorker) return;
     midiWorker->setMuted(on);
     screen->setMuted(midiWorker->isMuted);
+#ifdef APPBUILD
     parStore->ndc->setMuted(midiWorker->isMuted);
+#endif
     modified = true;
 }
 
 void LfoWidget::updateDeferChanges(bool on)
 {
-    midiWorker->updateDeferChanges(on);
+    if (midiWorker) midiWorker->updateDeferChanges(on);
     modified = true;
 }
 
 void LfoWidget::setRecord(bool on)
 {
-    midiWorker->setRecordMode(on);
+    if (midiWorker) midiWorker->setRecordMode(on);
     screen->setRecordMode(on);
 }
 
@@ -839,16 +847,43 @@ void LfoWidget::setChannelOut(int value)
 
 void LfoWidget::updatePortOut(int value)
 {
-    midiWorker->portOut = value;
+    if (midiWorker) midiWorker->portOut = value;
     modified = true;
 }
 
 void LfoWidget::updateChannelOut(int value)
 {
-    midiWorker->channelOut = value;
+    if (midiWorker) midiWorker->channelOut = value;
     modified = true;
 }
 
+void LfoWidget::storeParams(int ix, bool empty)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doStoreParams(ix, empty);
+#else
+    (void)ix;
+    (void)empty;
+#endif
+}
+
+void LfoWidget::restoreParams(int ix)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doRestoreParams(ix);
+#else
+    (void)ix;
+#endif
+}
+
+#ifdef APPBUILD
+QVector<Sample> LfoWidget::getCustomWave()
+{
+    return midiWorker->customWave;
+}
+
 bool LfoWidget::isModified()
 {
     return (modified || midiControl->isModified());
@@ -860,7 +895,7 @@ void LfoWidget::setModified(bool m)
     midiControl->setModified(m);
 }
 
-void LfoWidget::storeParams(int ix, bool empty)
+void LfoWidget::doStoreParams(int ix, bool empty)
 {
     parStore->temp.empty = empty;
     parStore->temp.muteOut = muteOut->isChecked();
@@ -877,13 +912,13 @@ void LfoWidget::storeParams(int ix, bool empty)
     parStore->temp.offs = offset->value();
     parStore->temp.waveForm = waveFormBox->currentIndex();
 
-    parStore->temp.wave = getCustomWave().mid(0, midiWorker->maxNPoints);
-    parStore->temp.muteMask = midiWorker->muteMask.mid(0, midiWorker->maxNPoints);
+    if (midiWorker) parStore->temp.wave = getCustomWave().mid(0, midiWorker->maxNPoints);
+    if (midiWorker) parStore->temp.muteMask = midiWorker->muteMask.mid(0, midiWorker->maxNPoints);
 
     parStore->tempToList(ix);
 }
 
-void LfoWidget::restoreParams(int ix)
+void LfoWidget::doRestoreParams(int ix)
 {
     midiWorker->applyPendingParChanges();
     if (parStore->list.at(ix).empty) return;
@@ -973,11 +1008,6 @@ void LfoWidget::copyParamsFrom(LfoWidget *fromWidget)
     updateWaveForm(tmp);
 }
 
-QVector<Sample> LfoWidget::getCustomWave()
-{
-    return midiWorker->customWave;
-}
-
 void LfoWidget::handleController(int ccnumber, int channel, int value)
 {
     bool m;
@@ -1112,3 +1142,21 @@ void LfoWidget::updateDisplay()
     needsGUIUpdate = false;
     midiWorker->needsGUIUpdate = false;
 }
+
+void LfoWidget::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+#endif
