@@ -36,18 +36,17 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
+#ifdef APPBUILD
 #include "globstore.h"
-#include "midilfo.h"
-#include "slider.h"
-#include "lfoscreen.h"
 #include "midicontrol.h"
 #include "managebox.h"
 #include "parstore.h"
-#include "cursor.h"
+#endif
 
-/*! This array holds the currently available frequency values.
- */
-const int lfoFreqValues[14] = {1, 2, 4, 8, 16, 24, 32, 64, 96, 128, 160, 192, 224, 256};
+#include "midilfo.h"
+#include "cursor.h"
+#include "slider.h"
+#include "lfoscreen.h"
 
 /*!
  * @brief GUI class associated with and controlling a MidiLfo worker
@@ -67,10 +66,10 @@ class LfoWidget : public QWidget
     Q_OBJECT
 
     MidiLfo *midiWorker;
+#ifdef APPBUILD
     GlobStore *globStore;
-    QVector<Sample> data;
+#endif
     bool modified;              /**< Is set to True if unsaved parameter modifications exist */
-    bool lastMute;              /**< Contains the mute state of the last waveForm point modified by mouse click*/
     bool dataChanged;
     bool needsGUIUpdate;
 /*!
@@ -100,18 +99,26 @@ class LfoWidget : public QWidget
  * @param mutedAdd If set to True, the module will be added in muted state
  * @param parent The parent widget of this module, i.e. MainWindow
  */
+#ifdef APPBUILD
     LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
             const QString& name = "", QWidget* parent=0);
-    ~LfoWidget();
 
     ParStore *parStore;
     MidiControl *midiControl;
+    ManageBox *manageBox;
+#else
+    LfoWidget(
+            bool compactStyle,
+            bool mutedAdd = false, bool inOutVisible = true,
+            QWidget* parent=0);
+#endif
+
+    ~LfoWidget();
     LfoScreen *screen;
     Cursor *cursor;
-    ManageBox *manageBox;
-
+    QVector<Sample> data;
     QStringList waveForms;
     QComboBox *chIn;
     QSpinBox  *ccnumberInBox;
@@ -139,6 +146,22 @@ class LfoWidget : public QWidget
     int freqBoxIndex;
     int waveFormBoxIndex;
 
+/*!
+* @brief Settor for the LfoWidget::channelOut spinbox setting the output
+* channel of this module.
+* @param value Number of the output channel to send data to
+*
+*/
+    void setChannelOut(int value);
+/*!
+* @brief Settor for the LfoWidget::portOut spinbox setting the output
+* port of this module.
+* @param value Number of the output port to send data to
+*
+*/
+    void setPortOut(int value);
+
+#ifdef APPBUILD
 /*!
 * @brief This function returns the MidiLfo instance associated with this GUI
 * Widget.
@@ -168,20 +191,6 @@ class LfoWidget : public QWidget
 */
     void copyParamsFrom(LfoWidget *fromWidget);
 /*!
-* @brief Settor for the LfoWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
-*
-*/
-    void setChannelOut(int value);
-/*!
-* @brief Settor for the LfoWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void setPortOut(int value);
-/*!
 * @brief Accessor for LfoWidget::modified.
 * @return True if unsaved parameter modifications exist
 *
@@ -193,11 +202,29 @@ class LfoWidget : public QWidget
 *
 */
     void setModified(bool);
+    void skipXmlElement(QXmlStreamReader& xml);
+/*!
+* @brief This function stores some module parameters in a parameter
+* list object
+*
+* @param Position index in the parameter list
+*/
+    void doStoreParams(int ix, bool empty);
+/*!
+* @brief This function restores some module parameters from the parameter
+* list object
+*
+* @param Position index in the parameter list
+*/
+    void doRestoreParams(int ix);
+#endif
 
 /* SIGNALS */
   signals:
 /*! @brief Currently not in use. */
     void patternChanged();
+/*! @brief Is re-emitted when received from screen and no MidiWorker present. */
+    void mouseSig(double, double, int, int);
 
 /* PUBLIC SLOTS */
   public slots:
@@ -211,8 +238,6 @@ class LfoWidget : public QWidget
     void updateTrigLegato(bool on);
     void setInOutBoxVisible(bool on);
 
-    void updateDisplay();
-
 /*!
 * @brief Slot for the LfoWidget::waveFormBox combobox setting the waveform
 * of this module.
@@ -296,26 +321,10 @@ class LfoWidget : public QWidget
 * @param mouseY Normalized mouse position on LfoScreen in Y
 * direction (0.0 ... 1.0)
 * @param buttons 1 for left mouse button, 2 for right mouse button
+* @param pressed 0 for mouse moved, 1 for mouse pressed, 2 for mouse released
 *
 */
-    void mouseMoved(double, double, int);
-/*!
-* @brief Slot for the LfoScreen::mousePressed signal. This function
-* mutes or sets a wave point when a mouse button is pressed before moving.
-*
-* The mouse events are generated by the LfoScreen.
-* It sets a MidiLfo::setCustomWavePoint and calls LfoWidget::newCustomOffset
-* if the left button is pressed. It toggles a MidiLfo::setMutePoint
-* if the right button is pressed before moving.
-*
-* @param mouseX Normalized mouse position on LfoScreen in X
-* direction (0.0 ... 1.0)
-* @param mouseY Normalized mouse position on LfoScreen in Y
-* direction (0.0 ... 1.0)
-* @param buttons 1 for left mouse button, 2 for right mouse button
-*
-*/
-    void mousePressed(double, double, int);
+    void mouseEvent(double, double, int, int pressed);
 /*!
 * @brief Slot for the LfoScreen::mouseWheel signal. This function changes the
 * offset by the steps the mouse wheel was turned.
@@ -371,25 +380,17 @@ class LfoWidget : public QWidget
 * @param on Set to True for deferring parameter changes to pattern end
 */
     void updateDeferChanges(bool on);
-/*!
-* @brief This function stores some module parameters in a parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
+
     void storeParams(int ix, bool empty = false);
-/*!
-* @brief This function restores some module parameters from the parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
     void restoreParams(int ix);
 
+#ifdef APPBUILD
+    void handleController(int ccnumber, int channel, int value);
+    void updateDisplay();
+#endif
     int getFramePtr() { return midiWorker->getFramePtr(); }
     int getNextTick() { return midiWorker->nextTick; }
     bool getReverse() { return midiWorker->reverse; }
-    void handleController(int ccnumber, int channel, int value);
 };
 
 #endif
