@@ -24,22 +24,8 @@
 #ifndef __MAIN_H
 #define __MAIN_H
 
-#include <QXmlStreamReader>
-
 #include "midievent.h"
 
-extern QString global_jack_session_uuid;
-/*!
-* @brief allows ignoring one XML element in the XML stream
-* passed by the caller.
-*
-* It also advances the stream read-in. It is used to
-* ignore unknown elements for both-ways-compatibility
-*
-* @param xml reference to QXmlStreamReader containing the open XML stream
-*/
-extern void skipXmlElement(QXmlStreamReader& xml);
-
 #define CT_FOOTSW       0x40
 
 #define MAX_PORTS         64
@@ -61,4 +47,36 @@ extern void skipXmlElement(QXmlStreamReader& xml);
     QCheckBox { font: 7pt; max-height: 20px;} \
     QGroupBox { font: 7pt; }"
 
+#ifndef SAMPLE_H
+#define SAMPLE_H
+/*! @brief Structure holding elements of a MIDI note or controller representing
+ * one point of a waveform
+ */
+    struct Sample {
+        int value;
+        int tick;
+        bool muted;
+    };
+#endif
+
+/*! This array holds the currently available frequency values.
+ */
+const int lfoFreqValues[14] = {1, 2, 4, 8, 16, 24, 32, 64, 96, 128, 160, 192, 224, 256};
+
+/*! @brief This array holds the currently available LFO size values.
+ */
+const int lfoSizeValues[12] = {1, 2, 3, 4, 5, 6, 7, 8, 12, 16, 24, 32};
+
+/*! @brief This array holds the currently available LFO resolution values.
+ */
+const int lfoResValues[9] = {1, 2, 4, 8, 16, 32, 64, 96, 192};
+
+/*! @brief This array holds the currently available Seq resolution values.
+ */
+const int seqResValues[5] = {1, 2, 4, 8, 16};
+
+/*! @brief This array holds the currently available Seq size values.
+ */
+const int seqSizeValues[11] = {1, 2, 3, 4, 5, 6, 7, 8, 16, 32};
+
 #endif
