@@ -193,24 +193,24 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
 
     fileNewAction = new QAction(QIcon(filenew_xpm), tr("&New"), this);
     fileNewAction->setShortcut(QKeySequence(QKeySequence::New));
-    fileNewAction->setToolTip(tr("Create new arpeggiator file"));
+    fileNewAction->setToolTip(tr("Create new QMidiArp session"));
     connect(fileNewAction, SIGNAL(triggered()), this, SLOT(fileNew()));
 
     fileOpenAction = new QAction(QIcon(fileopen_xpm), tr("&Open..."), this);
     fileOpenAction->setShortcut(QKeySequence(QKeySequence::Open));
-    fileOpenAction->setToolTip(tr("Open arpeggiator file"));
+    fileOpenAction->setToolTip(tr("Open QMidiArp file"));
     connect(fileOpenAction, SIGNAL(triggered()), this, SLOT(fileOpen()));
 
     fileSaveAction = new QAction(QIcon(filesave_xpm), tr("&Save"), this);
     fileSaveAction->setShortcut(QKeySequence(QKeySequence::Save));
-    fileSaveAction->setToolTip(tr("Save current arpeggiator file"));
+    fileSaveAction->setToolTip(tr("Save current QMidiArp session"));
     connect(fileSaveAction, SIGNAL(triggered()), this, SLOT(fileSave()));
     fileSaveAction->setDisabled(true);
 
     fileSaveAsAction = new QAction(QIcon(filesaveas_xpm), tr("Save &as..."),
             this);
     fileSaveAsAction->setToolTip(
-            tr("Save current arpeggiator file with new name"));
+            tr("Save current QMidiArp session with new name"));
     connect(fileSaveAsAction, SIGNAL(triggered()), this, SLOT(fileSaveAs()));
     fileSaveAsAction->setDisabled(true);
 
@@ -232,6 +232,7 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
     tempoSpin->setToolTip(tr("Tempo of internal clock"));
     connect(tempoSpin, SIGNAL(valueChanged(int)), this,
             SLOT(updateTempo(int)));
+    engine->midiControl->addMidiLearnMenu("Tempo", tempoSpin, 0);
 
     midiClockAction = new QAction(QIcon(midiclock_xpm),
             tr("&Use incoming MIDI Clock"), this);
@@ -383,9 +384,12 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
 #ifdef NSM
     if (nsm && nsm_is_active(nsm))
     {
-        fileNewAction->setDisabled(true);
-        fileOpenAction->setDisabled(true);
-        fileSaveAsAction->setDisabled(true);
+        fileNewAction->setText(tr("Clear"));
+        fileNewAction->setToolTip(tr("Clear QMidiArp session"));
+        fileOpenAction->setText(tr("Import file..."));
+        fileOpenAction->setToolTip(tr("Import QMidiArp file to NSM session"));
+        fileSaveAsAction->setText(tr("Export session..."));
+        fileSaveAsAction->setToolTip(tr("Export QMidiArp NSM session to file"));
         fileRecentlyOpenedFiles->setDisabled(true);
     }
 #endif
@@ -538,12 +542,15 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
 
     if (clonefrom >= 0) {
         midiWorker->reverse = engine->lfoWidget(clonefrom)->getReverse();
-        midiWorker->setFramePtr(engine->lfoWidget(clonefrom)->getFramePtr());
-        midiWorker->nextTick = engine->lfoWidget(clonefrom)->getNextTick();
+        midiWorker->setNextTick(engine->lfoWidget(clonefrom)->getNextTick());
     }
+    else if (engine->lfoWidgetCount())
+        midiWorker->setNextTick(engine->lfoWidget(0)->getNextTick());
 
     engine->addMidiLfo(midiWorker);
     engine->addLfoWidget(moduleWidget);
+    engine->sendGroove();
+
     count = engine->moduleWindowCount();
     moduleWidget->manageBox->parentDockID = count;
     moduleWidget->midiControl->parentDockID = count;
@@ -587,12 +594,15 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
 
     if (clonefrom >= 0) {
         midiWorker->reverse = engine->seqWidget(clonefrom)->getReverse();
-        midiWorker->setCurrentIndex(engine->seqWidget(clonefrom)->getCurrentIndex());
-        midiWorker->nextTick = engine->seqWidget(clonefrom)->getNextTick();
+        midiWorker->setNextTick(engine->seqWidget(clonefrom)->getNextTick());
     }
+    else if (engine->seqWidgetCount())
+        midiWorker->setNextTick(engine->seqWidget(0)->getNextTick());
 
     engine->addMidiSeq(midiWorker);
     engine->addSeqWidget(moduleWidget);
+    engine->sendGroove();
+
     count = engine->moduleWindowCount();
     moduleWidget->manageBox->parentDockID = count;
     moduleWidget->midiControl->parentDockID = count;
@@ -713,7 +723,16 @@ void MainWindow::fileNew()
 {
     if (isSave()) {
         clear();
+#ifdef NSM
+        if (nsm) {
+            filename = configFile;
+        }
+        else {
+            filename = "";
+        }
+#else
         filename = "";
+#endif
         updateWindowTitle();
         engine->setModified(false);
     }
@@ -721,8 +740,15 @@ void MainWindow::fileNew()
 
 void MainWindow::fileOpen()
 {
-    if (isSave())
+    if (isSave()) {
         chooseFile();
+#ifdef NSM
+        if (nsm) {
+            filename = configFile;
+            updateWindowTitle();
+        }
+#endif
+    }
 }
 
 void MainWindow::chooseFile()
@@ -745,7 +771,7 @@ void MainWindow::openFile(const QString& fn)
     QFile f(fn);
     if (!f.open(QIODevice::ReadOnly)) {
 #ifdef NSM
-        if (nsm_is_active(nsm)) {
+        if (nsm && nsm_is_active(nsm)) {
             filename = fn;
             //updateWindowTitle();
             return;
@@ -835,6 +861,8 @@ void MainWindow::readFilePartGlobal(QXmlStreamReader& xml)
         }
         else if (xml.isStartElement() && (xml.name() == "groove"))
             grooveWidget->readData(xml);
+        else if (xml.isStartElement() && (xml.name() == "midiControllers"))
+            engine->midiControl->readData(xml);
         else skipXmlElement(xml);
     }
     passWidget->setModified(false);
@@ -958,6 +986,7 @@ bool MainWindow::saveFile()
         xml.writeEndElement();
 
         grooveWidget->writeData(xml);
+        engine->midiControl->writeData(xml);
 
     xml.writeEndElement();
 
@@ -1000,6 +1029,12 @@ bool MainWindow::saveFile()
 void MainWindow::fileSaveAs()
 {
     saveFileAs();
+#ifdef NSM
+    if (nsm) {
+        filename = configFile;
+        updateWindowTitle();
+    }
+#endif
 }
 
 bool MainWindow::saveFileAs()
@@ -1062,6 +1097,12 @@ bool MainWindow::isSave()
 
 void MainWindow::closeEvent(QCloseEvent* e)
 {
+#ifdef NSM
+    if (nsm) {
+        writeRcFile();
+        e->accept();
+    } else
+#endif
     if (isSave()) {
         writeRcFile();
         e->accept();
@@ -1360,16 +1401,7 @@ void MainWindow::checkIfFirstModule()
         if (alsaMidi) midiClockAction->setEnabled(true);
         jackSyncAction->setEnabled(true);
         fileSaveAction->setEnabled(true);
-#ifdef NSM
-        if (nsm && nsm_is_active(nsm)) {
-            fileSaveAsAction->setDisabled(true);
-        }
-        else {
-#endif
-            fileSaveAsAction->setEnabled(true);
-#ifdef NSM
-        }
-#endif
+        fileSaveAsAction->setEnabled(true);
         showAllIOAction->setEnabled(true);
         hideAllIOAction->setEnabled(true);
         runAction->setEnabled(!(midiClockAction->isChecked()
@@ -1419,9 +1451,11 @@ bool MainWindow::installSignalHandlers()
         return false;
     }
 #ifdef NSM
-    if (sigaction(SIGTERM, &action, NULL) == -1) {
-        qWarning("sigaction() failed: %s", std::strerror(errno));
-        return false;
+    if (nsm && nsm_is_active(nsm)) {
+        if (sigaction(SIGTERM, &action, NULL) == -1) {
+            qWarning("sigaction() failed: %s", std::strerror(errno));
+            return false;
+        }
     }
 #endif
 
@@ -1496,6 +1530,23 @@ void MainWindow::ftb_update_orientation(Qt::Orientation orient)
     }
 }
 
+void MainWindow::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+
 #ifdef NSM
 int MainWindow::cb_nsm_open(const char *name, const char *display_name, const char *client_id, char **out_msg, void *userdata)
 {
@@ -1512,7 +1563,7 @@ int MainWindow::nsm_open(const char *name, const char *display_name, const char
     (void)out_msg;
     (void)display_name;
 
-    QString configFile = name;
+    configFile = name;
     if (!alsaMidi) {
         engine->driver->callJack(-1);
         engine->driver->callJack(engine->getPortCount(), client_id);
