@@ -111,7 +111,9 @@ class MainWindow : public QMainWindow
 
 #ifdef NSM
     static nsm_client_t *nsm;
+    QString configFile;
 #endif
+    void skipXmlElement(QXmlStreamReader& xml);
 /*!
 * @brief  opens a file dialog and calls either
 * MainWindow::openTextFile or
