@@ -93,6 +93,7 @@ MidiArp::MidiArp()
     noteBufPtr = 0;
     noteCount = 0;
     releaseNoteCount = 0;
+    triggerMode = 0;
     restartByKbd = false;
     trigByKbd = false;
     trigLegato = false;
@@ -102,7 +103,7 @@ MidiArp::MidiArp()
     minStepWidth = 1.0;
     maxOctave = 0;
     minOctave = 0;
-    nSteps = 0;
+    nSteps = 1.0;
     nPoints = 1;
     len = 0.5;       // note length
     vel = 0.8;  // velocity relative to global velocity
@@ -143,6 +144,7 @@ MidiArp::MidiArp()
     latchBuffer.resize(64);
     latchBufferCount = 0;
     lastLatchTick = 0;
+    trigDelayTicks = 2;
 
     returnNote.resize(128);
     returnVelocity.resize(128);
@@ -184,17 +186,13 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         if (!getPressedNoteCount() || trigLegato) {
             purgeLatchBuffer();
             if (restartByKbd) restartFlag = true;
-            if (trigByKbd) {
-                initArpTick(tick);
-                // if we have been triggered, remove pending release notes
-                if (release_time > 0) {
-                    for (int l1 = 0; l1 < noteCount; l1++) {
-                        if (notes[noteBufPtr][3][l1])
-                            removeNote(&notes[noteBufPtr][0][l1], -1, 0);
-                            releaseNoteCount--;
-                    }
+            // if we have been triggered, remove pending release notes
+            if (trigByKbd && release_time > 0) {
+                for (int l1 = 0; l1 < noteCount; l1++) {
+                    if (notes[noteBufPtr][3][l1])
+                        removeNote(&notes[noteBufPtr][0][l1], -1, 0);
+                        releaseNoteCount--;
                 }
-
             }
         }
         // modify buffer that is not accessed by arpeggio output
@@ -219,8 +217,8 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         noteCount++;
 
         if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
-        if (trigByKbd && ((noteCount == 1) || trigLegato)) {
-            nextTick = tick + 2; //schedDelayTicks;
+        if ((trigByKbd && (getPressedNoteCount() == 1)) || trigLegato) {
+            initArpTick(tick + trigDelayTicks);
             gotKbdTrig = true;
         }
     }
@@ -338,8 +336,8 @@ void MidiArp::copyNoteBuffer()
     noteBufPtr++;
     noteBufPtr%=2;
 
-    for (int l3 = 0; l3 < 4; l3++) {
-        for (int l2 = 0; l2 < noteCount; l2++) {
+    for (int l2 = 0; l2 < noteCount; l2++) {
+        for (int l3 = 0; l3 < 4; l3++) {
             notes[newBufPtr][l3][l2] = notes[noteBufPtr][l3][l2];
         }
     }
@@ -381,7 +379,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             else {
                 gotCC = true;
 
-                switch(c.toAscii()) {
+                switch(c.toLatin1()) {
                     case '(':
                         chordMode = true;
                         break;
@@ -519,21 +517,23 @@ bool MidiArp::advancePatternIndex(bool reset)
         restartFlag = false;
         applyPendingParChanges();
 
-
         switch (repeatPatternThroughChord) {
             case 1:
                 noteOfs++;
-                if (noteCount - 1 < patternMaxIndex + noteOfs) {
+                if ((noteCount - 1 < patternMaxIndex + noteOfs) || reset) {
                     noteOfs = 0;
                 }
                 break;
             case 2:
                 noteOfs--;
                 if ((noteCount -1 < patternMaxIndex) ||
-                    (noteOfs < patternMaxIndex)) {
+                    (noteOfs < patternMaxIndex) || reset) {
                     noteOfs = noteCount - 1;
                 }
                 break;
+            case 3:
+                if (noteCount) noteOfs = rand() % noteCount;
+                break;
             default:
                 noteOfs = 0;
         }
@@ -614,13 +614,31 @@ void MidiArp::initArpTick(int tick)
     grooveIndex = 0;
 }
 
+QString MidiArp::stripPattern(const QString& p_pattern)
+{
+    QString p = p_pattern;
+    patternLen = 0;
+    if (!p.count()) return (p);
+
+    QChar c = (p.at(p.count() - 1));
+    while (!c.isDigit() && (c != 'p') && (c != ')')) {
+        p = p.left(p.count() - 1);
+        if (p.count() < 1) break;
+        c = (p.at(p.count() - 1));
+    }
+
+    patternLen = p.count();
+
+    return (p);
+}
+
+
 void MidiArp::updatePattern(const QString& p_pattern)
 {
     int l1;
     QChar c;
 
     pattern = p_pattern;
-    patternLen = pattern.length();
     patternMaxIndex = 0;
     minStepWidth = 1.0;
     minOctave = 0;
@@ -633,16 +651,7 @@ void MidiArp::updatePattern(const QString& p_pattern)
     int oct = 0;
     int npoints = 0;
 
-    // strip off trailing control tokens
-    if (patternLen) {
-        c = (pattern.at(patternLen - 1));
-        while (!c.isDigit() && (c != 'p') && (c != ')')) {
-            pattern = pattern.left(patternLen - 1);
-            patternLen--;
-            if (patternLen < 1) break;
-            c = (pattern.at(patternLen - 1));
-        }
-    }
+    pattern = stripPattern(pattern);
 
     // determine some useful properties of the arp pattern,
     // number of octaves, step width and number of steps in beats and
@@ -660,7 +669,7 @@ void MidiArp::updatePattern(const QString& p_pattern)
             if (c.digitValue() > patternMaxIndex)
                 patternMaxIndex = c.digitValue();
         }
-        switch(c.toAscii()) {
+        switch(c.toLatin1()) {
             case '(':
                 chordmd = true;
                 chordindex = 0;
@@ -772,6 +781,7 @@ void MidiArp::updateReleaseTime(int val)
 
 void MidiArp::updateTriggerMode(int val)
 {
+    triggerMode = val;
     trigByKbd = ((val == 2) || (val == 4));
     restartByKbd = (val > 0);
     trigLegato = (val > 2);
@@ -845,6 +855,8 @@ void MidiArp::applyPendingParChanges()
 
 void MidiArp::setNextTick(int tick)
 {
+    if (nSteps == 0) return;
+
     returnTick = tick / (int)(nSteps*TPQN) * (int)(nSteps*TPQN);
     patternIndex = 0;
     currentNoteTick = returnTick;
