@@ -219,3 +219,20 @@ void MidiControl::setCcList(const QVector<MidiCC> &p_ccList)
 {
     ccList = p_ccList;
 }
+
+void MidiControl::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
