@@ -79,7 +79,7 @@ class MidiControl : public QWidget
     MidiCC pendingCC;
 
   public:
-    MidiControl(QWidget *parent);
+    MidiControl(QWidget *parent = 0);
     ~MidiControl();
     QStringList names;      /**< Contains a list of convenient names
                                     of controllable widgets */
@@ -109,6 +109,7 @@ class MidiControl : public QWidget
 * @param count Internal identifier of the controllable QWidget
 */
     void addMidiLearnMenu(const QString &name, QWidget *widget, int count = 0);
+    void skipXmlElement(QXmlStreamReader& xml);
 
   signals:
 /*! @brief Connected to Engine::setMidiLearn() to listen for incoming events.
