@@ -61,8 +61,8 @@ MidiSeq::MidiSeq()
     res = 4;
     nPoints = 16;
     maxNPoints = 16;
-    notelength = 74;
-    notelengthDefer = 74;
+    notelength = 60;
+    notelengthDefer = 60;
     portOut = 0;
     channelOut = 0;
     currentIndex = 0;
@@ -75,6 +75,7 @@ MidiSeq::MidiSeq()
     isMutedDefer = false;
     deferChanges = false;
     parChangesPending = false;
+    lastMute = false;
     dataChanged = false;
     needsGUIUpdate = false;
 
@@ -83,15 +84,15 @@ MidiSeq::MidiSeq()
     int step = TPQN / res;
     Sample sample;
     sample.value = 60;
-    customWave.resize(512);
-    muteMask.resize(512);
-    for (l1 = 0; l1 < 512; l1++) {
+    customWave.resize(2048);
+    muteMask.resize(2048);
+    for (l1 = 0; l1 < 2048; l1++) {
             sample.tick = lt;
             sample.muted = false;
             customWave.replace(l1, sample);
             lt+=step;
     }
-    muteMask.fill(false, 512);
+    muteMask.fill(false, 2048);
 }
 
 MidiSeq::~MidiSeq(){
@@ -192,6 +193,14 @@ void MidiSeq::advancePatternIndex()
     int pivot = abs(loopMarker);
     reflect = pingpong;
 
+    if (curLoopMode == 6) {
+        if (pivot)
+            currentIndex = rand() % pivot;
+        else
+            currentIndex = rand() % npoints;
+        return;
+    }
+
     if (reverse) {
         if (!pivot) pivot = npoints;
         if (currentIndex == pivot - 1) applyPendingParChanges();
@@ -273,12 +282,28 @@ int MidiSeq::clip(int value, int min, int max, bool *outOfRange)
     return(tmp);
 }
 
+void MidiSeq::updateResolution(int val)
+{
+    res = val;
+    resizeAll();
+}
+
+void MidiSeq::updateSize(int val)
+{
+    size = val;
+    resizeAll();
+}
+
 void MidiSeq::updateLoop(int val)
 {
     backward = val&1;
     pingpong = val&2;
     enableLoop = !(val&4);
     curLoopMode = val;
+    if (seqFinished) {
+        seqFinished = false;
+        setCurrentIndex(0);
+    }
 }
 
 void MidiSeq::updateNoteLength(int val)
@@ -321,10 +346,40 @@ void MidiSeq::updateQueueTempo(int val)
     queueTempo = (double)val;
 }
 
-void MidiSeq::setCustomWavePoint(double mouseX, double mouseY)
+int MidiSeq::setCustomWavePoint(double mouseX, double mouseY)
 {
     currentRecStep = mouseX * res * size;
     setRecordedNote(12 * (mouseY * nOctaves + baseOctave));
+    return (currentRecStep);
+}
+
+int MidiSeq::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
+{
+    int ix = 0;
+
+    if ((mouseY < 0) && (pressed != 2)) {
+        if (mouseX < 0) mouseX = 0;
+        if (buttons == 2) mouseX = - mouseX;
+        setLoopMarkerMouse(mouseX);
+        return (0);
+    }
+
+    if ((mouseX > 1) || (mouseX < 0) || (mouseY > 1) || (mouseY < 0)) return (0);
+
+    if (buttons == 2) {
+        if (pressed == 1) {
+            lastMute = toggleMutePoint(mouseX);
+            ix = lastMute;
+        }
+        else if (pressed == 0)
+            ix = setMutePoint(mouseX, lastMute);
+    }
+    else if (pressed != 2) {
+        ix = setCustomWavePoint(mouseX, mouseY);
+    }
+    dataChanged = true;
+
+    return (ix);
 }
 
 void MidiSeq::setLoopMarkerMouse(double mouseX)
@@ -383,6 +438,7 @@ void MidiSeq::resizeAll()
     }
 
     if (!loopMarker) nPoints = npoints;
+    if (abs(loopMarker) >= npoints) loopMarker = 0;
     dataChanged = true;
 }
 
@@ -400,7 +456,7 @@ bool MidiSeq::toggleMutePoint(double mouseX)
     return(!m);
 }
 
-void MidiSeq::setMutePoint(double mouseX, bool on)
+int MidiSeq::setMutePoint(double mouseX, bool on)
 {
     Sample sample;
     int loc = mouseX * (res * size);
@@ -409,6 +465,7 @@ void MidiSeq::setMutePoint(double mouseX, bool on)
     sample.muted = on;
     customWave.replace(loc, sample);
     muteMask.replace(loc, on);
+    return (loc);
 }
 
 void MidiSeq::setCurrentIndex(int ix)
