@@ -602,3 +602,20 @@ void ParStore::updateOnlyPattern(bool on)
 {
     onlyPatternList.replace(sender()->property("index").toInt() - 1, on);
 }
+
+void ParStore::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
