@@ -215,7 +215,7 @@ void SeqDriver::calcCurrentTick(double tmpTime) {
     }
     else if (useJackSync) {
         jPos = jackSync->getCurrentPos();
-        if (jPos.beats_per_minute > 0) requestedTempo = jPos.beats_per_minute;
+        if (jPos.beats_per_minute > 0.01) requestedTempo = jPos.beats_per_minute;
 
         m_current_tick = (uint64_t)(jPos.frame - tempoChangeFrame) * TPQN  * tempo
                 / jPos.frame_rate / 60.
@@ -240,7 +240,7 @@ void SeqDriver::initTempo()
 {
     if (useJackSync) {
         jPos = jackSync->getCurrentPos();
-        if (jPos.beats_per_minute > 0)
+        if (jPos.beats_per_minute > 0.01)
             tempo = jPos.beats_per_minute;
         else
             tempo = internalTempo;
@@ -268,7 +268,7 @@ void SeqDriver::sendMidiEvent(MidiEvent outEv, int n_tick, unsigned outport, uns
 
     ev.type = outEv.type;
     if (ev.type == EV_NOTEON) {
-        snd_seq_ev_set_note(&ev, 0, outEv.data, outEv.value, length);
+        snd_seq_ev_set_note(&ev, 0, outEv.data, outEv.value, length * 80 / tempo);
     }
     else if (ev.type == EV_CONTROLLER) {
         ev.data.control.param = outEv.data;
