@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009, 2010, 2011, 2012 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -76,22 +76,25 @@ class SeqDriver : public DriverBase {
         double aTimeToDelta(snd_seq_real_time_t* atime);
         const snd_seq_real_time_t* deltaToATime(double curtime);
         snd_seq_remove_events_t *remove_ev;
-        void calcClockRatio();
+        void calcClockRatio(double realtime);
 
         void initTempo();
-        bool callJack(int portcount);
+        bool callJack(int portcount, const QString & clientname=PACKAGE);
 
         JackDriver *jackSync;
         jack_position_t jPos;
 
         int midiTick;
         int lastRatioTick;
+        int midiTempoRefreshTick;
         int lastSchedTick;
         int jackOffsetTick;
+        int tempoChangeTick;
+        uint64_t tempoChangeFrame;
 
         double clockRatio;         /* duration of one tick, in nanoseconds; based on current tempo */
-        snd_seq_real_time_t delta, realTime;
-        snd_seq_real_time_t tmpTime;
+        double tempoChangeTime;
+        snd_seq_real_time_t atime;
 
 
     public:
@@ -106,15 +109,17 @@ class SeqDriver : public DriverBase {
             bool (* midi_event_received_callback)(void * context, MidiEvent ev),
             void (* tick_callback)(void * context, bool echo_from_trig));
         ~SeqDriver();
-        void getTime();
-        int getClientId(); /** overloaded over DriverBase */
+        double getCurrentTime();
+        void calcCurrentTick(double time); /** calculate m_current_tick based on realTime */
+        void requestTempo(double bpm); /** reimplemented over DriverBase */
+        void setTempo(double bpm); /** reimplemented over DriverBase */
+        int getClientId(); /** reimplemented over DriverBase */
         void run();
 
    public slots:
         void setTransportStatus(bool run); /** is pure in DriverBase */
-        void setTempo(int bpm); /** overloaded over DriverBase */
-        void setUseMidiClock(bool on); /** overloaded over DriverBase */
-        void setUseJackTransport(bool on); /** overloaded over DriverBase */
+        void setUseMidiClock(bool on); /** reimplemented over DriverBase */
+        void setUseJackTransport(bool on); /** reimplemented over DriverBase */
 };
 
 #endif
