@@ -34,53 +34,27 @@
 #include "pixmaps/seqrecord.xpm"
 
 
+#ifdef APPBUILD
 SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     int portCount, bool compactStyle,
     bool mutedAdd, bool inOutVisible, const QString& name, QWidget *parent):
-    QWidget(parent), midiWorker(p_midiWorker),
-    globStore(p_globStore), modified(false)
+    QWidget(parent),
+    midiWorker(p_midiWorker),
+    globStore(p_globStore),
+    modified(false)
 {
-    int l1;
-
     midiControl = new MidiControl(this);
-
     manageBox = new ManageBox("Seq:", true, this);
-
-    // Display group box on right
-    QGroupBox *dispBox = new QGroupBox(tr("Display"), this);
-
-    QSignalMapper *dispSignalMapper = new QSignalMapper(this);
-    QLabel *dispLabel[4];
-    QString dispText[4] = {tr("&F"), tr("&U"), tr("&M"), tr("&L")};
-    QString dispToolTip[4] = {tr("Full"), tr("Upper"), tr("Mid"), tr("Lower")};
-    QGridLayout *dispBoxLayout = new QGridLayout;
-
-    for (int l1 = 0; l1 < 4; l1++) {
-        dispLabel[l1] = new QLabel(dispText[l1],dispBox);
-        dispVert[l1] = new QCheckBox(this);
-        connect(dispVert[l1], SIGNAL(toggled(bool)), dispSignalMapper, SLOT(map()));
-        dispSignalMapper->setMapping(dispVert[l1], l1);
-        dispVert[l1]->setAutoExclusive(true);
-        dispLabel[l1]->setBuddy(dispVert[l1]);
-        dispVert[l1]->setToolTip(dispToolTip[l1]);
-        dispBoxLayout->addWidget(dispLabel[l1], 0, l1);
-        dispBoxLayout->addWidget(dispVert[l1], 1, l1);
-    }
-
-    dispVert[0]->setChecked(true);
-    dispVertical = 0;
-    connect(dispSignalMapper, SIGNAL(mapped(int)),
-             this, SLOT(updateDispVert(int)));
-
-    QVBoxLayout* dispLayout = new QVBoxLayout;
-    dispLayout->addLayout(dispBoxLayout);
-
-    if (compactStyle) {
-        dispLayout->setSpacing(1);
-        dispLayout->setMargin(2);
-    }
-
-    dispBox->setLayout(dispLayout);
+#else
+SeqWidget::SeqWidget(
+    bool compactStyle,
+    bool mutedAdd, bool inOutVisible, QWidget *parent):
+    QWidget(parent),
+    modified(false)
+{
+    midiWorker = NULL;
+#endif
+    int l1;
 
     // Input group box on right top
     QGroupBox *inBox = new QGroupBox(tr("Input"), this);
@@ -161,12 +135,6 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     // Output group box on right bottom
     QGroupBox *portBox = new QGroupBox(tr("Output"), this);
 
-    QLabel *portLabel = new QLabel(tr("&Port"), portBox);
-    portOut = new QComboBox(portBox);
-    portLabel->setBuddy(portOut);
-    for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
-    connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
-
     QLabel *channelLabel = new QLabel(tr("C&hannel"), portBox);
     channelOut = new QComboBox(portBox);
     channelLabel->setBuddy(channelOut);
@@ -174,10 +142,19 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     connect(channelOut, SIGNAL(activated(int)), this,
             SLOT(updateChannelOut(int)));
 
-
     QGridLayout *portBoxLayout = new QGridLayout;
-    portBoxLayout->addWidget(portLabel, 0, 0);
-    portBoxLayout->addWidget(portOut, 0, 1);
+
+#ifdef APPBUILD
+        QLabel *portLabel = new QLabel(tr("&Port"), portBox);
+        portOut = new QComboBox(portBox);
+        portLabel->setBuddy(portOut);
+        for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
+        connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
+
+        portBoxLayout->addWidget(portLabel, 0, 0);
+        portBoxLayout->addWidget(portOut, 0, 1);
+#endif
+
     portBoxLayout->addWidget(channelLabel, 1, 0);
     portBoxLayout->addWidget(channelOut, 1, 1);
 
@@ -200,8 +177,9 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     connect(hideInOutBoxAction, SIGNAL(toggled(bool)), this, SLOT(setInOutBoxVisible(bool)));
 
     QVBoxLayout *inOutBoxLayout = new QVBoxLayout;
+#ifdef APPBUILD
     inOutBoxLayout->addWidget(manageBox);
-    inOutBoxLayout->addWidget(dispBox);
+#endif
     inOutBoxLayout->addWidget(inBox);
     inOutBoxLayout->addWidget(portBox);
     inOutBoxLayout->addStretch();
@@ -216,10 +194,8 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     screen->setToolTip(
         tr("Right button to mute points, left button to draw custom wave"));
     screen->setMinimumHeight(SEQSCR_MIN_H);
-    connect(screen, SIGNAL(mouseMoved(double, double, int)), this,
-            SLOT(mouseMoved(double, double, int)));
-    connect(screen, SIGNAL(mousePressed(double, double, int)), this,
-            SLOT(mousePressed(double, double, int)));
+    connect(screen, SIGNAL(mouseEvent(double, double, int, int)), this,
+            SLOT(mouseEvent(double, double, int, int)));
 
     cursor = new Cursor('S', this);
 
@@ -230,8 +206,10 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     muteOut->setDefaultAction(muteOutAction);
     muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(35,20));
-    midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
 
+#ifdef APPBUILD
+    midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
+#endif
     deferChangesAction = new QAction("D", this);
     deferChangesAction->setToolTip(tr("Defer mute, velocity, note length and transpose to pattern end"));
     deferChangesAction->setCheckable(true);
@@ -244,15 +222,16 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     loopBox = new QComboBox(seqBox);
     QStringList names;
     names.clear();
-    names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-";
+    names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-" << "RANDM";
     loopBox->insertItems(0, names);
     loopBox->setCurrentIndex(0);
     loopBox->setToolTip(tr("Loop, bounce or play once going forward or backward"));
     loopBox->setMinimumContentsLength(5);
     connect(loopBox, SIGNAL(activated(int)), this,
             SLOT(updateLoop(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("LoopMode", loopBox, 6);
-
+#endif
     QLabel *recordButtonLabel = new QLabel(tr("Re&cord"), seqBox);
     recordAction = new QAction(QIcon(seqrecord_xpm), tr("Re&cord"), seqBox);
     recordAction->setToolTip(tr("Record step by step"));
@@ -261,7 +240,9 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     recordButton->setDefaultAction(recordAction);
     recordButtonLabel->setBuddy(recordButton);
     connect(recordAction, SIGNAL(toggled(bool)), this, SLOT(setRecord(bool)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("RecordToggle", recordButton, 3);
+#endif
 
     QLabel *resBoxLabel = new QLabel(tr("&Resolution"),
             seqBox);
@@ -277,13 +258,15 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     resBox->setMinimumContentsLength(3);
     connect(resBox, SIGNAL(activated(int)), this,
             SLOT(updateRes(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Resolution", resBox, 4);
+#endif
 
     QLabel *sizeBoxLabel = new QLabel(tr("&Length"), seqBox);
     sizeBox = new QComboBox(seqBox);
     sizeBoxLabel->setBuddy(sizeBox);
     names.clear();
-    names << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8";
+    names << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8" << "16" << "32";
     sizeBox->insertItems(0, names);
     sizeBox->setCurrentIndex(3);
     sizeBoxIndex = 3;
@@ -291,33 +274,67 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     sizeBox->setMinimumContentsLength(3);
     connect(sizeBox, SIGNAL(activated(int)), this,
             SLOT(updateSize(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Size", sizeBox, 5);
+#endif
 
+    QSignalMapper *dispSignalMapper = new QSignalMapper(this);
+    QLabel *dispLabel[4];
+    QString dispText[4] = {tr("&F"), tr("&U"), tr("&M"), tr("&L")};
+    QString dispToolTip[4] = {tr("Full"), tr("Upper"), tr("Mid"), tr("Lower")};
+
+    QHBoxLayout *dispBoxLayout = new QHBoxLayout;
+
+    dispBoxLayout->addWidget(new QLabel(tr("Display")));
+    dispBoxLayout->addStretch(10);
+    for (int l1 = 0; l1 < 4; l1++) {
+        dispLabel[l1] = new QLabel(dispText[l1],this);
+        dispVert[l1] = new QCheckBox(this);
+        connect(dispVert[l1], SIGNAL(toggled(bool)), dispSignalMapper, SLOT(map()));
+        dispSignalMapper->setMapping(dispVert[l1], l1);
+        dispVert[l1]->setAutoExclusive(true);
+        dispLabel[l1]->setBuddy(dispVert[l1]);
+        dispVert[l1]->setToolTip(dispToolTip[l1]);
+        dispBoxLayout->addWidget(dispLabel[l1]);
+        dispBoxLayout->addWidget(dispVert[l1]);
+    }
+    dispBoxLayout->addStretch();
+
+    dispVert[0]->setChecked(true);
+    dispVertical = 0;
+    connect(dispSignalMapper, SIGNAL(mapped(int)),
+             this, SLOT(updateDispVert(int)));
 
     velocity = new Slider(0, 127, 1, 8, 64, Qt::Horizontal,
             tr("Veloc&ity"), seqBox);
     connect(velocity, SIGNAL(valueChanged(int)), this,
             SLOT(updateVelocity(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("Velocity", velocity, 1);
+#endif
 
-
-    notelength = new Slider(0, 127, 1, 16, 64, Qt::Horizontal,
+    notelength = new Slider(0, 127, 1, 16, 60, Qt::Horizontal,
             tr("N&ote Length"), seqBox);
     connect(notelength, SIGNAL(valueChanged(int)), this,
             SLOT(updateNoteLength(int)));
+#ifdef APPBUILD
     midiControl->addMidiLearnMenu("NoteLength", notelength, 2);
+#endif
 
     transpose = new Slider(-24, 24, 1, 2, 0, Qt::Horizontal,
             tr("&Transpose"), seqBox);
     connect(transpose, SIGNAL(valueChanged(int)), this,
             SLOT(updateTranspose(int)));
-
+#ifdef APPBUILD
+    midiControl->addMidiLearnMenu("Transpose", transpose, 8);
+#endif
 
     QGridLayout* sliderLayout = new QGridLayout;
-    sliderLayout->addWidget(velocity, 1, 0);
-    sliderLayout->addWidget(notelength, 2, 0);
-    sliderLayout->addWidget(transpose, 3, 0);
-    sliderLayout->setRowStretch(4, 1);
+    sliderLayout->addLayout(dispBoxLayout, 1, 0);
+    sliderLayout->addWidget(velocity, 2, 0);
+    sliderLayout->addWidget(notelength, 3, 0);
+    sliderLayout->addWidget(transpose, 4, 0);
+    sliderLayout->setRowStretch(5, 1);
     if (compactStyle) {
         sliderLayout->setSpacing(1);
         sliderLayout->setMargin(2);
@@ -351,12 +368,14 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     widgetLayout->addWidget(hideInOutBoxButton, 0);
     widgetLayout->addWidget(inOutBox, 0);
 
-    parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
-    midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 7);
-    connect(parStore, SIGNAL(store(int, bool)),
-             this, SLOT(storeParams(int, bool)));
-    connect(parStore, SIGNAL(restore(int)),
-             this, SLOT(restoreParams(int)));
+#ifdef APPBUILD
+        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
+        midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 7);
+        connect(parStore, SIGNAL(store(int, bool)),
+                 this, SLOT(storeParams(int, bool)));
+        connect(parStore, SIGNAL(restore(int)),
+                 this, SLOT(restoreParams(int)));
+#endif
 
     muteOutAction->setChecked(mutedAdd);
 
@@ -371,9 +390,12 @@ SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
 
 SeqWidget::~SeqWidget()
 {
+#ifdef APPBUILD
     delete parStore;
+#endif
 }
 
+#ifdef APPBUILD
 MidiSeq *SeqWidget::getMidiWorker()
 {
     return (midiWorker);
@@ -560,7 +582,7 @@ void SeqWidget::readData(QXmlStreamReader& xml)
                     updateVelocity(tmp);
                 }
                 else if (xml.name() == "noteLength") {
-                    notelength->setValue(xml.readElementText().toInt() / 2);
+                    notelength->setValue(xml.readElementText().toInt());
                 }
                 else if (xml.name() == "transp") {
                     tmp = xml.readElementText().toInt();
@@ -623,6 +645,7 @@ void SeqWidget::readData(QXmlStreamReader& xml)
     }
     modified = false;
 }
+#endif
 
 void SeqWidget::setEnableNoteIn(bool on)
 {
@@ -644,56 +667,56 @@ void SeqWidget::setChIn(int value)
 
 void SeqWidget::updateChIn(int value)
 {
-    midiWorker->chIn = value;
+    if (midiWorker) midiWorker->chIn = value;
     modified = true;
 }
 
 void SeqWidget::updateEnableNoteIn(bool on)
 {
-    midiWorker->enableNoteIn = on;
+    if (midiWorker) midiWorker->enableNoteIn = on;
     modified = true;
 }
 
 void SeqWidget::updateEnableNoteOff(bool on)
 {
-    midiWorker->enableNoteOff = on;
+    if (midiWorker) midiWorker->enableNoteOff = on;
     modified = true;
 }
 
 void SeqWidget::updateEnableVelIn(bool on)
 {
-    midiWorker->enableVelIn = on;
+    if (midiWorker) midiWorker->enableVelIn = on;
     modified = true;
 }
 
 void SeqWidget::updateEnableRestartByKbd(bool on)
 {
-    midiWorker->restartByKbd = on;
+    if (midiWorker) midiWorker->restartByKbd = on;
     modified = true;
 }
 
 void SeqWidget::updateEnableTrigByKbd(bool on)
 {
-    midiWorker->trigByKbd = on;
+    if (midiWorker) midiWorker->trigByKbd = on;
     modified = true;
 }
 
 void SeqWidget::updateTrigLegato(bool on)
 {
-    midiWorker->trigLegato = on;
+    if (midiWorker) midiWorker->trigLegato = on;
     modified = true;
 }
 
 void SeqWidget::updateNoteLength(int val)
 {
-    midiWorker->updateNoteLength(val + val);
+    if (midiWorker) midiWorker->updateNoteLength(sliderToTickLen(val));
     modified = true;
 }
 
 void SeqWidget::updateWaveForm(int val)
 {
     (void)val;
-    midiWorker->getData(&data);
+    if (midiWorker) midiWorker->getData(&data);
     screen->updateData(data);
     modified = true;
 }
@@ -701,8 +724,9 @@ void SeqWidget::updateWaveForm(int val)
 void SeqWidget::setRecord(bool on)
 {
     recordMode = on;
-    midiWorker->setRecordMode(on);
     screen->setRecordMode(on);
+    if (!midiWorker) return;
+    midiWorker->setRecordMode(on);
     screen->setCurrentRecStep(midiWorker->currentRecStep);
 }
 
@@ -710,6 +734,7 @@ void SeqWidget::updateRes(int val)
 {
     if (val > 4) return;
     resBoxIndex = val;
+    if (!midiWorker) return;
     midiWorker->res = seqResValues[val];
     midiWorker->resizeAll();
     midiWorker->getData(&data);
@@ -720,9 +745,10 @@ void SeqWidget::updateRes(int val)
 
 void SeqWidget::updateSize(int val)
 {
-    if (val > 7) return;
+    if (val > 9) return;
     sizeBoxIndex = val;
-    midiWorker->size = val + 1;
+    if (!midiWorker) return;
+    midiWorker->size = sizeBox->currentText().toInt();
     midiWorker->resizeAll();
     midiWorker->getData(&data);
     screen->setCurrentRecStep(midiWorker->currentRecStep);
@@ -732,60 +758,44 @@ void SeqWidget::updateSize(int val)
 
 void SeqWidget::updateLoop(int val)
 {
-    if (val > 5) return;
-    midiWorker->updateLoop(val);
+    if (val > 6) return;
+    if (midiWorker) midiWorker->updateLoop(val);
     modified = true;
 }
 
 
 void SeqWidget::updateVelocity(int val)
 {
-    midiWorker->updateVelocity(val);
+    if (midiWorker) midiWorker->updateVelocity(val);
     modified = true;
 }
 
 void SeqWidget::updateTranspose(int val)
 {
-    midiWorker->updateTranspose(val);
+    if (midiWorker) midiWorker->updateTranspose(val);
     modified = true;
 }
 
-void SeqWidget::mouseMoved(double mouseX, double mouseY, int buttons)
+void SeqWidget::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
 {
-    if ((mouseX > 1) || (mouseX < 0) || (mouseY > 1)) return;
-    if (buttons == 2) {
-        midiWorker->setMutePoint(mouseX, lastMute);
+    if (!midiWorker) {
+        emit mouseSig(mouseX, mouseY, buttons, pressed);
     }
     else {
-        midiWorker->setCustomWavePoint(mouseX, mouseY);
-        screen->setCurrentRecStep(midiWorker->currentRecStep);
+        midiWorker->mouseEvent(mouseX, mouseY, buttons, pressed);
     }
-    midiWorker->getData(&data);
-    screen->updateData(data);
-    modified = true;
-}
 
-void SeqWidget::mousePressed(double mouseX, double mouseY, int buttons)
-{
-    if (mouseY < 0) {
+    if ((mouseY < 0) && (pressed != 2)) { // we have to recalculate loopMarker for screen update
         if (mouseX < 0) mouseX = 0;
         if (buttons == 2) mouseX = - mouseX;
-        midiWorker->setLoopMarkerMouse(mouseX);
-        screen->setLoopMarker(midiWorker->loopMarker);
-        modified = true;
-        return;
+        const int npoints = data.count() - 1;
+        int lm;
+        if (mouseX > 0) lm = mouseX * (double)npoints + .5;
+        else lm = mouseX * (double)npoints - .5;
+        if (abs(lm) >= npoints) lm = 0;
+        screen->setLoopMarker(lm);
+        screen->updateDraw();
     }
-
-    if ((mouseX > 1) || (mouseX < 0) || (mouseY > 1)) return;
-
-    if (buttons == 2) {
-        lastMute = midiWorker->toggleMutePoint(mouseX);
-    } else {
-        midiWorker->setCustomWavePoint(mouseX, mouseY);
-        screen->setCurrentRecStep(midiWorker->currentRecStep);
-    }
-    midiWorker->getData(&data);
-    screen->updateData(data);
     modified = true;
 }
 
@@ -797,15 +807,18 @@ void SeqWidget::setInOutBoxVisible(bool on)
 
 void SeqWidget::setMuted(bool on)
 {
+    if (!midiWorker) return;
     midiWorker->setMuted(on);
     screen->setMuted(midiWorker->isMuted);
+#ifdef APPBUILD
     parStore->ndc->setMuted(midiWorker->isMuted);
+#endif
     modified = true;
 }
 
 void SeqWidget::updateDeferChanges(bool on)
 {
-    midiWorker->updateDeferChanges(on);
+    if (midiWorker) midiWorker->updateDeferChanges(on);
     modified = true;
 }
 
@@ -823,27 +836,16 @@ void SeqWidget::setChannelOut(int value)
 
 void SeqWidget::updatePortOut(int value)
 {
-    midiWorker->portOut = value;
+    if (midiWorker) midiWorker->portOut = value;
     modified = true;
 }
 
 void SeqWidget::updateChannelOut(int value)
 {
-    midiWorker->channelOut = value;
+    if (midiWorker) midiWorker->channelOut = value;
     modified = true;
 }
 
-bool SeqWidget::isModified()
-{
-    return (modified || midiControl->isModified());
-}
-
-void SeqWidget::setModified(bool m)
-{
-    modified = m;
-    midiControl->setModified(m);
-}
-
 void SeqWidget::setDispVert(int mode)
 {
     dispVert[mode]->setChecked(true);
@@ -876,8 +878,8 @@ void SeqWidget::updateDispVert(int mode)
     }
 
     dispVertical = mode;
-    midiWorker->nOctaves = noct;
-    midiWorker->baseOctave = baseoct;
+    if (midiWorker) midiWorker->nOctaves = noct;
+    if (midiWorker) midiWorker->baseOctave = baseoct;
     screen->nOctaves = noct;
     screen->baseOctave = baseoct;
     screen->update();
@@ -885,6 +887,39 @@ void SeqWidget::updateDispVert(int mode)
 }
 
 void SeqWidget::storeParams(int ix, bool empty)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doStoreParams(ix, empty);
+#else
+    (void)ix;
+    (void)empty;
+#endif
+}
+
+void SeqWidget::restoreParams(int ix)
+{
+#ifdef APPBUILD
+    // have to do this for moc not caring for APPBUILD flag
+    doRestoreParams(ix);
+#else
+    (void)ix;
+#endif
+}
+
+#ifdef APPBUILD
+bool SeqWidget::isModified()
+{
+    return (modified || midiControl->isModified());
+}
+
+void SeqWidget::setModified(bool m)
+{
+    modified = m;
+    midiControl->setModified(m);
+}
+
+void SeqWidget::doStoreParams(int ix, bool empty)
 {
     parStore->temp.empty = empty;
     parStore->temp.muteOut = muteOut->isChecked();
@@ -906,7 +941,7 @@ void SeqWidget::storeParams(int ix, bool empty)
     parStore->tempToList(ix);
 }
 
-void SeqWidget::restoreParams(int ix)
+void SeqWidget::doRestoreParams(int ix)
 {
     midiWorker->applyPendingParChanges();
     if (parStore->list.at(ix).empty) return;
@@ -914,9 +949,11 @@ void SeqWidget::restoreParams(int ix)
         midiWorker->customWave.replace(l1, parStore->list.at(ix).wave.at(l1));
         midiWorker->muteMask.replace(l1, parStore->list.at(ix).muteMask.at(l1));
     }
-    sizeBox->setCurrentIndex(parStore->list.at(ix).size);
+    sizeBoxIndex = parStore->list.at(ix).size;
+    sizeBox->setCurrentIndex(sizeBoxIndex);
     midiWorker->size = sizeBox->currentText().toInt();
-    midiWorker->res = seqResValues[parStore->list.at(ix).res];
+    resBoxIndex = parStore->list.at(ix).res;
+    midiWorker->res = seqResValues[resBoxIndex];
     midiWorker->resizeAll();
     midiWorker->setLoopMarker(parStore->list.at(ix).loopMarker);
     screen->setLoopMarker(parStore->list.at(ix).loopMarker);
@@ -924,7 +961,7 @@ void SeqWidget::restoreParams(int ix)
     resBox->setCurrentIndex(parStore->list.at(ix).res);
     loopBox->setCurrentIndex(parStore->list.at(ix).loopMode);
     if (!parStore->onlyPatternList.at(ix)) {
-        midiWorker->notelength = parStore->list.at(ix).notelen;
+        midiWorker->notelength = sliderToTickLen(parStore->list.at(ix).notelen);
         midiWorker->transp = parStore->list.at(ix).transp;
         midiWorker->vel = parStore->list.at(ix).vel;
         setDispVert(parStore->list.at(ix).dispVertical);
@@ -1030,12 +1067,12 @@ void SeqWidget::handleController(int ccnumber, int channel, int value)
 
                 case 1:
                         sval = min + ((double)value * (max - min) / 127);
-                        midiWorker->vel = sval;
+                        midiWorker->updateVelocity(sval);
                 break;
 
                 case 2:
                         sval = min + ((double)value * (max - min) / 127);
-                        midiWorker->notelength = sval + sval;
+                        midiWorker->updateNoteLength(sliderToTickLen(sval));
                 break;
 
                 case 3: if (min == max) {
@@ -1078,6 +1115,11 @@ void SeqWidget::handleController(int ccnumber, int channel, int value)
                         else return;
                 break;
 
+                case 8:
+                        sval = min + ((double)value * (max - min) / 127);
+                        midiWorker->updateTranspose(sval - 24);
+                break;
+
                 default:
                 break;
             }
@@ -1108,7 +1150,7 @@ void SeqWidget::updateDisplay()
     if (!(needsGUIUpdate || midiWorker->needsGUIUpdate)) return;
 
     transpose->setValue(midiWorker->transp);
-    notelength->setValue(midiWorker->notelength/2);
+    notelength->setValue(tickLenToSlider(midiWorker->notelength));
     velocity->setValue(midiWorker->vel);
     muteOutAction->setChecked(midiWorker->isMuted);
     screen->setMuted(midiWorker->isMuted);
@@ -1123,3 +1165,20 @@ void SeqWidget::updateDisplay()
     needsGUIUpdate = false;
     midiWorker->needsGUIUpdate = false;
 }
+void SeqWidget::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+#endif
